@@ -18,7 +18,7 @@ from ._version import __version__
 ## Standard library imports
 
 # Generic Operating System Services
-import os, io, time
+import os, io, time, re
 
 # Python Runtime Services
 import traceback
@@ -343,10 +343,9 @@ class LaunchNotebookHandler(IPythonHandler):
             data = json.loads(self.request.body)
             requirementsFile = data.get('requirementsFile')     # we use .get() for params that are not required
             dataFiles = data.get('dataFiles')                   # we use .get() for params that are not required
-            compress = data['compress']
             uuid = data['uuid']
             timestamp = data['timestamp']
-            IOLoop.current().run_in_executor(None, launch_notebook, requirementsFile, dataFiles, compress, uuid, timestamp)
+            IOLoop.current().run_in_executor(None, launch_notebook, requirementsFile, dataFiles, uuid, timestamp)
             self.write(json.dumps({'message': 'success'}))
         except Exception as e:
             self.set_status(500)
@@ -382,13 +381,13 @@ def get_launch_status(key):
         lock.release()
     return data
 
-class GetLaunchUploadProgressHandler(IPythonHandler):
+class GetUploadProgressHandler(IPythonHandler):
     @authenticated
     async def post(self):
         try:
             data = json.loads(self.request.body)
-            uuid = data['uuid']
-            json_map = await IOLoop.current().run_in_executor(None, get_launch_upload_progress, uuid)
+            keys = data['keys']
+            json_map = await IOLoop.current().run_in_executor(None, get_upload_progress, keys)
             if json_map == {}:
                 self.set_status(204) # 204 No content
             else:
@@ -399,39 +398,51 @@ class GetLaunchUploadProgressHandler(IPythonHandler):
             jupyter_log.error(optumi_start(self) + str(e))
             if DEBUG: raise e
 
-def get_launch_upload_progress(key):
+def get_upload_progress(keys):
     data = {}
     try:
         lock.acquire()
-        data = uploadProgress[key]
+        if keys == []:
+            for key in uploadProgress:
+                data[key] = uploadProgress[key]
+        else:
+            for key in keys:
+                if key in uploadProgress:
+                    data[key] = uploadProgress[key]
     except:
         pass
     finally:
         lock.release()
     return data
 
-class GetLaunchCompressionProgressHandler(IPythonHandler):
+class GetCompressionProgressHandler(IPythonHandler):
     @authenticated
     async def post(self):
         try:
             data = json.loads(self.request.body)
-            uuid = data['uuid']
-            json_map = await IOLoop.current().run_in_executor(None, get_launch_compression_progress, uuid)
+            keys = data['keys']
+            json_map = await IOLoop.current().run_in_executor(None, get_compression_progress, keys)
             if json_map == {}:
                 self.set_status(204) # 204 No content
             else:
                 self.write(json.dumps(json_map))
         except Exception as e:
             self.set_status(500)
-            self.write(json.dumps({'message': 'Encountered error while getting upload progress'}))
+            self.write(json.dumps({'message': 'Encountered error while getting compression progress'}))
             jupyter_log.error(optumi_start(self) + str(e))
             if DEBUG: raise e
 
-def get_launch_compression_progress(key):
+def get_compression_progress(keys):
     data = {}
     try:
         lock.acquire()
-        data = compressionProgress[key]
+        if keys == []:
+            for key in compressionProgress:
+                data[key] = compressionProgress[key]
+        else:
+            for key in keys:
+                if key in compressionProgress:
+                    data[key] = compressionProgress[key]
     except:
         pass
     finally:
@@ -691,10 +702,9 @@ class PullWorkloadStatusUpdatesHandler(IPythonHandler):
             data = json.loads(self.request.body)
             uuids = data['uuids']
             lastInitializingLines = data['lastInitializingLines']
-            lastUploadingLines = data['lastUploadingLines']
-            lastRequisitioningLines = data['lastRequisitioningLines']
+            lastPreparingLines = data['lastPreparingLines']
             lastRunningLines = data['lastRunningLines']
-            response = await IOLoop.current().run_in_executor(None, pull_workload_status_updates, uuids, lastInitializingLines, lastUploadingLines, lastRequisitioningLines, lastRunningLines)
+            response = await IOLoop.current().run_in_executor(None, pull_workload_status_updates, uuids, lastInitializingLines, lastPreparingLines, lastRunningLines)
             self.set_status(401 if response.geturl().endswith('/login') else response.getcode())
             self.write(response.read())
             if response.getcode() >= 300: jupyter_log.info(optumi_start(self) + str(response))
@@ -736,17 +746,92 @@ class PullModuleStatusUpdateHandler(IPythonHandler):
             jupyter_log.error(optumi_start(self) + str(e))
             if DEBUG: raise e
 
-class SaveNotebookOutputFileHandler(IPythonHandler):
+class ListFilesHandler(IPythonHandler):
+    @authenticated
+    async def get(self):
+        try:
+            response = await IOLoop.current().run_in_executor(None, list_files)
+            self.set_status(401 if response.geturl().endswith('/login') else response.getcode())
+            self.write(response.read())
+            if response.getcode() >= 300: jupyter_log.info(optumi_start(self) + str(response))
+        except Exception as e:
+            self.set_status(500)
+            self.write(json.dumps({'message': 'Encountered error while listing files'}))
+            jupyter_log.error(optumi_start(self) + str(e))
+            if DEBUG: raise e
+
+class DeleteFilesHandler(IPythonHandler):
+    @authenticated
+    async def post(self):
+        try:
+            data = json.loads(self.request.body)
+            filePaths = data['filePaths']
+            response = await IOLoop.current().run_in_executor(None, delete_files, filePaths)
+            self.set_status(401 if response.geturl().endswith('/login') else response.getcode())
+            self.write(response.read())
+            if response.getcode() >= 300: jupyter_log.info(optumi_start(self) + str(response))
+        except Exception as e:
+            self.set_status(500)
+            self.write(json.dumps({'message': 'Encountered error while listing files'}))
+            jupyter_log.error(optumi_start(self) + str(e))
+            if DEBUG: raise e
+
+class CancelProgressHandler(IPythonHandler):
+    @authenticated
+    async def post(self):
+        try:
+            data = json.loads(self.request.body)
+            key = data['key']
+            IOLoop.current().run_in_executor(None, cancel_progress, key)
+            self.write(json.dumps({'message': 'success'}))
+        except Exception as e:
+            self.set_status(500)
+            self.write(json.dumps({'message': 'Encountered error while cancelling uploading files'}))
+            jupyter_log.error(optumi_start(self) + str(e))
+            if DEBUG: raise e
+
+def cancel_progress(key):
+    data = {}
+    try:
+        lock.acquire()
+        if key in compressionProgress:
+            compressionProgress[key]['progress'] = -1
+        if key in uploadProgress:
+            uploadProgress[key]['progress'] = -1
+    except:
+        pass
+    finally:
+        lock.release()
+    return data
+
+class UploadFilesHandler(IPythonHandler):
+    @authenticated
+    async def post(self):
+        try:
+            data = json.loads(self.request.body)
+            key = data['key']
+            fileNames = data['fileNames']
+            compress = data['compress']
+            IOLoop.current().run_in_executor(None, upload_files, key, fileNames, compress)
+            self.write(json.dumps({'message': 'success'}))
+        except Exception as e:
+            self.set_status(500)
+            self.write(json.dumps({'message': 'Encountered error while uploading files'}))
+            jupyter_log.error(optumi_start(self) + str(e))
+            if DEBUG: raise e
+
+class DownloadFilesHandler(IPythonHandler):
     @authenticated
     async def post(self):
         try:
             data = json.loads(self.request.body)
             workloadUUID = data['workloadUUID']
             moduleUUID = data['moduleUUID']
-            name = data['name']
+            key = data['key']
             files = data['files']
+            sizes = data['sizes']
             overwrite = data['overwrite']
-            response = await IOLoop.current().run_in_executor(None, save_notebook_output_file, workloadUUID, moduleUUID, name, files, overwrite)
+            response = await IOLoop.current().run_in_executor(None, download_files, workloadUUID, moduleUUID, key, files, sizes, overwrite)
             # We only expect a response if something went wrong
             if response != None: raise response
         except (ConnectionError, URLError) as e:
@@ -761,13 +846,13 @@ class SaveNotebookOutputFileHandler(IPythonHandler):
             jupyter_log.error(optumi_start(self) + str(e))
             if DEBUG: raise e
 
-class GetFileDownloadProgressHandler(IPythonHandler):
+class GetDownloadProgressHandler(IPythonHandler):
     @authenticated
     async def post(self):
         try:
             data = json.loads(self.request.body)
-            name = data['name']
-            json_map = await IOLoop.current().run_in_executor(None, get_file_download_progress, name)
+            keys = data['keys']
+            json_map = await IOLoop.current().run_in_executor(None, get_download_progress, keys)
             if json_map == {}:
                 self.set_status(204) # No content
             else:
@@ -778,11 +863,17 @@ class GetFileDownloadProgressHandler(IPythonHandler):
             jupyter_log.error(optumi_start(self) + str(e))
             if DEBUG: raise e
 
-def get_file_download_progress(key):
+def get_download_progress(keys):
     data = {}
     try:
         lock.acquire()
-        data = downloadProgress[key]
+        if keys == []:
+            for key in downloadProgress:
+                data[key] = downloadProgress[key]
+        else:
+            for key in keys:
+                if key in downloadProgress:
+                    data[key] = downloadProgress[key]
     except:
         pass
     finally:
@@ -996,8 +1087,8 @@ def setup_handlers(server_app):
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/setup-notebook'), SetupNotebookHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/launch-notebook'), LaunchNotebookHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/get-launch-status'), GetLaunchStatusHandler)])
-    web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/get-launch-compression-progress'), GetLaunchCompressionProgressHandler)])
-    web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/get-launch-upload-progress'), GetLaunchUploadProgressHandler)])
+    web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/get-compression-progress'), GetCompressionProgressHandler)])
+    web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/get-upload-progress'), GetUploadProgressHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/stop-notebook'), StopNotebookHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/teardown-notebook'), TeardownNotebookHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/get-machines'), GetMachinesHandler)])
@@ -1011,8 +1102,12 @@ def setup_handlers(server_app):
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/pull-workload-config'), PullWorkloadConfigHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/push-workload-config'), PushWorkloadConfigHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/pull-module-status-updates'), PullModuleStatusUpdateHandler)])
-    web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/save-notebook-output-file'), SaveNotebookOutputFileHandler)])
-    web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/get-file-download-progress'), GetFileDownloadProgressHandler)])
+    web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/upload-files'), UploadFilesHandler)])
+    web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/cancel-progress'), CancelProgressHandler)])
+    web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/delete-files'), DeleteFilesHandler)])
+    web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/list-files'), ListFilesHandler)])
+    web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/download-files'), DownloadFilesHandler)])
+    web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/get-download-progress'), GetDownloadProgressHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/get-total-billing'), GetTotalBillingHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/get-detailed-billing'), GetDetailedBillingHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/delete-machine'), DeleteMachineHandler)])
@@ -1065,6 +1160,18 @@ def login_rest_server(loginName, password):
 def logout():
     URL = get_path() + '/logout'
     try:
+        try:
+            lock.acquire()
+            # These maps are no longer relevant
+            compressionProgress = {}
+            uploadProgress = {}
+            launchStatus = {}
+            downloadProgress = {}
+            sessionSockets = {}
+        except:
+            pass
+        finally:
+            lock.release()
         req = request.Request(URL)
         return request.urlopen(req)
     except HTTPError as e:
@@ -1179,11 +1286,10 @@ def setup_notebook(name, timestamp, notebook, nbConfig):
     except HTTPError as e:
         return e
 
-def launch_notebook(requirementsFile, dataFiles, compress, uuid, timestamp):
+def launch_notebook(requirementsFile, dataFiles, uuid, timestamp):
     URL = get_path() + '/exp/jupyterlab/launch-notebook'
     try:
         form = MultiPartForm()
-        form.add_field('compressed', str(compress))
         form.add_field('uuid', uuid)
         ## Send this list as a file since it can have arbitrary length and cause issues for the REST Interface if sent as an array
         form.add_file('dataFileNames', 'dataFileNames', fileHandle=io.BytesIO(','.join(dataFiles).encode('utf-8')))
@@ -1205,62 +1311,13 @@ def launch_notebook(requirementsFile, dataFiles, compress, uuid, timestamp):
             lock.release()
         if requirementsFile != None:
             form.add_file('requirementsFile', 'requirements.txt', fileHandle=io.BytesIO(requirementsFile.encode('utf-8')))
-            # form.add_file('requirementsFile', requirementsFile, fileHandle=open(requirementsFile, 'rb'))
-        filesToZip = [] # We use this only if we are compressing files
-        zipFile = "" # We use this only if we are compressing files
-        if dataFiles != None and len(dataFiles) > 0:
-            ## Check for files in chunks of 100
-            while len(dataFiles) > 100:
-                chunk = dataFiles[:100]
-                for exists, file in zip(json.load(check_if_files_exist(chunk))['exists'], chunk):
-                    try:
-                        if not exists:
-                            if compress:
-                                filesToZip.append(file)
-                            else:
-                                form.add_file('dataFiles', file, fileHandle=open(file, 'rb'))
-                    except Exception as e:
-                        raise e
-                dataFiles = dataFiles[100:]
-            ## Check last chunk
-            for exists, file in zip(json.load(check_if_files_exist(dataFiles))['exists'], dataFiles):
-                try:
-                    if not exists:
-                        if compress:
-                            filesToZip.append(file)
-                        else:
-                            form.add_file('dataFiles', file, fileHandle=open(file, 'rb'))
-                except Exception as e:
-                    raise e
-        if len(filesToZip) > 0:
-            zipFile = zip_files(uuid, filesToZip)
-            form.add_file('dataFiles', 'dataFiles.zip', fileHandle=open(zipFile, 'rb'))
-        else:
-            try:
-                lock.acquire()
-                compressionProgress[uuid] = {'read': 1, 'total': 1}
-            except CancelledError:
-                raise
-            except:
-                pass
-            finally:
-                lock.release()
 
-        b = bytes(form)
-        data = UploadProgressOpener(b, uuid)
-
-        ## This check should be kept in sync with max-file-size and max-request-size in Swagger2SpringBoot.java
-        maxRequestSize = 5 * 1024 * 1024 * 1024
-        if len(b) > maxRequestSize:
-            raise CancelledError("Upload limit (5GiB) exceeded")
+        data = bytes(form)
 
         req = request.Request(URL, data=data)
         req.add_header('Content-type', form.get_content_type())
         req.add_header('Content-length', len(data))
         response = request.urlopen(req)
-        if zipFile != "":
-            response.getcode() # wait for the response to come back
-            os.remove(zipFile)
         try:
             lock.acquire()
             if response.getcode() == 200:
@@ -1270,27 +1327,6 @@ def launch_notebook(requirementsFile, dataFiles, compress, uuid, timestamp):
             pass
         finally:
             lock.release()
-    except CancelledError as err:
-        try:
-            lock.acquire()
-            launchStatus[uuid]['status'] = "Failed"
-            launchStatus[uuid]['message'] = err.message
-        except:
-            pass
-        finally:
-            lock.release()
-        raise
-    except FileNotFoundError as err:
-        try:
-            lock.acquire()
-            launchStatus[uuid]['status'] = "Failed"
-            launchStatus[uuid]['message'] = "Unable to find upload file(s)"
-            launchStatus[uuid]['snackbar'] = 'Unable to find: ' + str(err).split(' ')[-1] + '. Please check the path in "Upload Files".'
-        except:
-            pass
-        finally:
-            lock.release()
-        raise
     except:
         try:
             lock.acquire()
@@ -1311,8 +1347,6 @@ def stop_notebook(uuid):
         try:
             lock.acquire()
             launchStatus[uuid]['status'] = "Failed"
-            compressionProgress[uuid] = None
-            uploadProgress[uuid] = None
         except:
             pass
         finally:
@@ -1335,8 +1369,6 @@ def teardown_notebook(uuid):
         try:
             lock.acquire()
             launchStatus[uuid]['status'] = "Failed"
-            compressionProgress[uuid] = None
-            uploadProgress[uuid] = None
         except:
             pass
         finally:
@@ -1349,6 +1381,146 @@ def teardown_notebook(uuid):
     except HTTPError as e:
         return e
 
+def upload_cleanup(key, pairs):
+    for response, fileName in pairs:
+        response.read()
+        try:
+            lock.acquire()
+            uploadProgress[key]['progress'] = -1
+        except:
+            pass
+        finally:
+            lock.release()
+        if fileName != None:
+            try:
+                os.remove(fileName)
+            except Exception as e:
+                print(e)
+
+def upload_files(key, fileNames, compress):
+    URL = get_path() + '/exp/jupyterlab/upload-files'
+    try:
+        filesToUpload = []
+        ## Check for files in chunks of 100
+        while len(fileNames) > 100:
+            chunk = fileNames[:100]
+            for exists, file in zip(json.load(check_if_files_exist(chunk))['exists'], chunk):
+                if not exists:
+                    filesToUpload.append((file, os.path.getsize(file)))
+            fileNames = fileNames[100:]
+        ## Check last chunk
+        for exists, file in zip(json.load(check_if_files_exist(fileNames))['exists'], fileNames):
+            if not exists:
+                filesToUpload.append((file, os.path.getsize(file)))
+        
+        if len(filesToUpload) > 0:
+            # Sort by file size
+            filesToUpload.sort(key=lambda x:x[1], reverse=True)
+
+            if compress:
+                try:
+                    lock.acquire()
+                    compressionProgress[key] = {'progress': 0, 'total': len(filesToUpload)}
+                except Exception as e:
+                    print(e)
+                    pass
+                finally:
+                    lock.release()
+
+            MAX_SIZE = 5 * 1024 * 1024 * 1024
+
+            fileChunks = [[]]
+            totalSize = 0
+            for file, size in filesToUpload:
+                if size > MAX_SIZE:
+                    # TODO:JJ We should let the user know we can;t upload a file because it is too large
+                    continue
+                elif totalSize + size > MAX_SIZE:
+                    # If the next file takes us over 5GB, this is the end of the chunk
+                    if compress:
+                        zipFile = zip_files(key, str(len(fileChunks)), fileChunks[-1])
+                        fileChunks[-1] = [zipFile]
+                        
+                    # Reset variables for the next chunk of files
+                    fileChunks.append([])
+                    totalSize = 0
+                else: 
+                    fileChunks[-1].append(file)
+            # Compress the last chunk if necessary
+            if compress:
+                zipFile = zip_files(key, str(len(fileChunks)), fileChunks[-1])
+                fileChunks[-1] = [zipFile]
+
+            # We need to add up the total upload size before we start uploading
+            totalSize = 0
+            for chunk in fileChunks:
+                for file in chunk:
+                    totalSize += os.path.getsize(file)
+            try:
+                lock.acquire()
+                if key in compressionProgress: 
+                    compressionProgress[key]['progress'] = -1
+                uploadProgress[key] = { 'progress': 0, 'total': totalSize }
+            except Exception as e:
+                print(e)
+                pass
+            finally:
+                lock.release()
+
+            responses = []
+            for chunk in fileChunks:
+                form = MultiPartForm()
+                for file in chunk:
+                    form.add_file('files', file, fileHandle=open(file, 'rb'))
+
+                form.add_field('jupyterHome', jupyterHome)
+                form.add_field('compressed', str(compress))
+
+                b = bytes(form)
+                data = UploadProgressOpener(b, key)
+
+                req = request.Request(URL, data=data)
+                req.add_header('Content-type', form.get_content_type())
+                req.add_header('Content-length', len(data))
+                res = request.urlopen(req)
+                if compress:
+                    responses.append((res, chunk[0]))
+                else:
+                    responses.append((res, None))
+
+                # This thread will set the upload state to none when it is finished
+                Thread(target=upload_cleanup, args = (key, responses, )).start()
+        else:
+            # We want to record the no files need to be uploaded, otherwise the extension will keep asking
+            try:
+                lock.acquire()
+                if compress:
+                    compressionProgress[key] = {'progress': -1, 'total': 0 }
+                uploadProgress[key] = {'progress': -1, 'total': 0 }
+            except Exception as e:
+                print(e)
+                pass
+            finally:
+                lock.release()
+    except HTTPError as e:
+        # Clean up ongoing progress in the case of a failure
+        try:
+            lock.acquire()
+            if compress:
+                # Cancel compression progress
+                if key in compressionProgress:
+                    compressionProgress[key] = {'progress': -1, 'total': 0 }
+            # Cancel upload progress
+            if key in uploadProgress:
+                uploadProgress[key] = {'progress': -1, 'total': 0 }
+        except Exception as e:
+            print(e)
+            pass
+        finally:
+            lock.release()
+
+        return e
+
 def check_if_files_exist(fileNames):
     URL = get_path() + '/exp/jupyterlab/check-if-files-exist'
     try:
@@ -1486,7 +1658,7 @@ def push_workload_status_update(uuid, phase, update):
     except HTTPError as e:
         return e
 
-def pull_workload_status_updates(uuids, lastInitializingLines, lastUploadingLines, lastRequisitioningLines, lastRunningLines):
+def pull_workload_status_updates(uuids, lastInitializingLines, lastPreparingLines, lastRunningLines):
     URL = get_path() + '/exp/jupyterlab/pull-workload-status-updates'
     try:
         form = MultiPartForm()
@@ -1494,10 +1666,8 @@ def pull_workload_status_updates(uuids, lastInitializingLines, lastUploadingLine
             form.add_field('uuids', uuid)
         for lastInitializingLine in lastInitializingLines:
             form.add_field('lastInitializingLines', str(lastInitializingLine))
-        for lastUploadingLine in lastUploadingLines:
-            form.add_field('lastUploadingLines', str(lastUploadingLine))
-        for lastRequisitioningLine in lastRequisitioningLines:
-            form.add_field('lastRequisitioningLines', str(lastRequisitioningLine))
+        for lastPreparingLine in lastPreparingLines:
+            form.add_field('lastPreparingLines', str(lastPreparingLine))
         for lastRunningLine in lastRunningLines:
             form.add_field('lastRunningLines', str(lastRunningLine))
         data = bytes(form)
@@ -1521,8 +1691,8 @@ def pull_module_status_updates(workloadUUIDs, moduleUUIDs, lastUpdateLines, last
             form.add_field('lastUpdateLines', str(lastUpdateLine))
         for lastOutputLine in lastOutputLines:
             form.add_field('lastOutputLines', str(lastOutputLine))
-        for lastPatche in lastPatches:
-            form.add_field('lastPatches', str(lastPatche))
+        for lastPatch in lastPatches:
+            form.add_field('lastPatches', str(lastPatch))
         data = bytes(form)
 
         req = request.Request(URL, data=data)
@@ -1532,58 +1702,153 @@ def pull_module_status_updates(workloadUUIDs, moduleUUIDs, lastUpdateLines, last
     except HTTPError as e:
         return e
 
-def save_notebook_output_file(workloadUUID, moduleUUID, name, files, overwrite):
-    URL = get_path() + '/exp/jupyterlab/get-notebook-output-file'
+def list_files():
+    URL = get_path() + '/exp/jupyterlab/list-files'
     try:
-        for file in files:
-            form = MultiPartForm()
-            form.add_field('workloadUUID', workloadUUID)
-            form.add_field('moduleUUID', moduleUUID)
-            form.add_field('fileName', file)
-            data = bytes(form)
+        req = request.Request(URL)
+        return request.urlopen(req)
+    except HTTPError as e:
+        return e
 
-            req = request.Request(URL, data=data)
-            req.add_header('Content-type', form.get_content_type())
-            req.add_header('Content-length', len(data))
+def delete_files(filePaths):
+    URL = get_path() + '/exp/jupyterlab/delete-files'
+    try:
+        form = MultiPartForm()
+        for filePath in filePaths:
+            form.add_field('filePaths', str(filePath))
+        data = bytes(form)
 
-            response = request.urlopen(req)
-            total = response.getheader('content-length')
+        req = request.Request(URL, data=data)
+        req.add_header('Content-type', form.get_content_type())
+        req.add_header('Content-length', len(data))
+        return request.urlopen(req)
+    except HTTPError as e:
+        return e
+
+def save_file(fileName, content, overwrite):
+    file = fileName
+    if not overwrite:
+        newName = file
+        num = 1
+        while os.path.exists(newName) and os.path.isfile(newName):
+            f, ext = os.path.splitext(file)
+            newName = f + '(' + str(num) + ')' + ext
+            num += 1
+        file = newName
+    dirs = os.path.dirname(file)
+    if dirs != "":
+        os.makedirs(dirs, exist_ok=True)
+    with open(file, "wb") as f:
+        f.write(base64.decodebytes(content.getvalue()))
+
+def add_content(content, decoded):
+    # Remove starting or ending " so we can look at only , when splitting the string
+    if decoded != '' and decoded[0] == '"':
+        decoded = decoded[1:]
+    if decoded != '' and decoded[-1] == '"':
+        decoded = decoded[:-1]
+    encoded = decoded.encode('ascii')
+    content.write(encoded)
+    try:
+        lock.acquire()
+        downloadProgress[key]['progress'] = downloadProgress[key]['progress'] + len(encoded)
+    except:
+        pass
+    finally:
+        lock.release()
+
+def download_files_helper(key, form, fileNames, overwrite):
+    URL = get_path() + '/exp/jupyterlab/get-notebook-output-file'
+
+    data = bytes(form)
+
+    req = request.Request(URL, data=data)
+    req.add_header('Content-type', form.get_content_type())
+    req.add_header('Content-length', len(data))
+
+    response = request.urlopen(req)
+    total = response.getheader('content-length')
+
+    blocksize = 4096
+    
+    content = io.BytesIO()
+    while True:
+        read = response.read(blocksize)
+        if not read:
+            break
+        decoded = read.decode("ascii")
+        if decoded != '' and decoded[0] == '[':
+            # Remove the opening ["
+            decoded = decoded[1:]
+        if decoded != '' and decoded[-1] == ']':
+            # Remove the ending "]"
+            decoded = decoded[:-1]
+        if ',' in decoded:
+            split = decoded.split(',')
+            for chunk in split[:-1]:
+                add_content(content, chunk)
+                save_file(fileNames.pop(0), content, overwrite)
+                content = io.BytesIO()
+            # Handle the last chunk like the else case below
+            add_content(content, split[-1])
+        else:
+            add_content(content, decoded)
+
+    # Save the last file
+    save_file(fileNames.pop(0), content, overwrite)
+
+def download_files(workloadUUID, moduleUUID, key, files, sizes, overwrite):
+    try:
+        total = sum(sizes)
+        try:
+            lock.acquire()
+            downloadProgress[key] = { 'progress': 0, 'total': total }
+        except:
+            pass
+        finally:
+            lock.release()
+
+        filesToDownload = zip(files, sizes)
+        # Sort by file size
+        filesToDownload = sorted(filesToDownload, key=lambda x:x[1], reverse=True)
+
+        MAX_SIZE = 5 * 1024 * 1024 * 1024
+
+        totalSize = 0
+        form = MultiPartForm()
+        fileNames = []
+        for file, size in filesToDownload:
+            if size > MAX_SIZE:
+                # TODO:JJ We should let the user know we can;t upload a file because it is too large
+                continue
+            elif totalSize + size > MAX_SIZE:
+                form.add_field('workloadUUID', workloadUUID)
+                form.add_field('moduleUUID', moduleUUID)
+
+                download_files_helper(key, form, fileNames, overwrite)
+
+                # Reset variables for the next chunk of files
+                totalSize = 0
+                form = MultiPartForm()
+                fileNames = []
+            else: 
+                form.add_field('fileNames', file)
+                fileNames.append(file)
+        # Download the remaining files
+        form.add_field('workloadUUID', workloadUUID)
+        form.add_field('moduleUUID', moduleUUID)
+
+        download_files_helper(key, form, fileNames, overwrite)
+
+        # Make sure we mark the download as completed
+        try:
+            lock.acquire()
+            downloadProgress[key] = { 'progress': -1, 'total': total }
+        except:
+            pass
+        finally:
+            lock.release()
 
-            buf = io.BytesIO()
-            if total:
-                total = int(total)
-                blocksize = max(4096, total//100)
-                downloadProgress[name] = { 'read': 0, 'total': total }
-            else:
-                blocksize = 4096 # just made something up
-            size = 0
-            while True:
-                read = response.read(blocksize)
-                if not read:
-                    break
-                buf.write(read)
-                size += len(read)
-                if total:
-                    try:
-                        lock.acquire()
-                        downloadProgress[name]['read'] = size
-                    except:
-                        pass
-                    finally:
-                        lock.release()
-            if not overwrite:
-                newName = file
-                num = 1
-                while os.path.exists(newName) and os.path.isfile(newName):
-                    f, ext = os.path.splitext(file)
-                    newName = f + '(' + str(num) + ')' + ext
-                    num += 1
-                file = newName
-            dirs = os.path.dirname(file)
-            if dirs != "":
-                os.makedirs(dirs, exist_ok=True)
-            with open(file, "wb") as f:
-                f.write(base64.decodebytes(buf.getvalue()))
         return
     except HTTPError as e:
         return e
@@ -1670,7 +1935,7 @@ def create_checkout(items, redirect):
 
 def hash_file(fileName):
     BLOCKSIZE = 65536
-    hasher = hashlib.sha1()
+    hasher = hashlib.md5()
     with open(fileName, 'rb') as afile:
         buf = afile.read(BLOCKSIZE)
         while len(buf) > 0:
@@ -1682,19 +1947,10 @@ def hash_file(fileName):
 ####    Zip files
 ####
 
-def zip_files(uuid, files):
-    path = uuid + '.zip'
+def zip_files(key, inc, files):
+    # make the path safe for Linux and windows, while being unique
+    path = '.' + re.sub(r'\W+', '', key + inc) + '.zip'
     files.sort(key=lambda x: os.path.getsize(x))
-    # add up total files
-    try:
-        lock.acquire()
-        compressionProgress[uuid] = {'read': 0, 'total': len(files)}
-    except CancelledError:
-        raise
-    except:
-        pass
-    finally:
-        lock.release()
     # writing files to a zipfile 
     with ZipFile(path, 'w', ZIP_DEFLATED) as zip:
         # writing each file one by one 
@@ -1702,9 +1958,9 @@ def zip_files(uuid, files):
             zip.write(file)
             try:
                 lock.acquire()
-                if compressionProgress[uuid] == None:
+                if compressionProgress[key]['progress'] == -1:
                     raise CancelledError("Compression canceled")
-                compressionProgress[uuid]['read'] = compressionProgress[uuid]['read'] + 1
+                compressionProgress[key]['progress'] = compressionProgress[key]['progress'] + 1
             except CancelledError:
                 raise
             except:
@@ -1728,8 +1984,6 @@ class UploadProgressOpener:
         self._f = io.BytesIO(_bytes)
         self._key = key
         self._total = len(_bytes)
-        self._uploadProgress = uploadProgress
-        self._uploadProgress[self._key] = {'read': 0, 'total': self._total}
 
     def __len__(self):
         return self._total
@@ -1744,9 +1998,9 @@ class UploadProgressOpener:
         data = self._f.read(n_bytes)
         try:
             lock.acquire()
-            if self._uploadProgress[self._key] == None:
+            if uploadProgress[self._key]['progress'] == -1:
                 raise CancelledError("Upload canceled")
-            self._uploadProgress[self._key]['read'] = self._uploadProgress[self._key]['read'] + len(data)
+            uploadProgress[self._key]['progress'] = uploadProgress[self._key]['progress'] + len(data)
         except CancelledError:
             raise
         except:
