@@ -15,7 +15,7 @@ import { OptumiMetadataTracker } from "./models/OptumiMetadataTracker";
 import { NotebookTracker } from "@jupyterlab/notebook";
 import { Snackbar } from "./models/Snackbar";
 import { ServerConnection } from '@jupyterlab/services';
-import LogScaleUtils from "./utils/LogScaleUtils";
+import ExpScaleUtils from "./utils/ExpScaleUtils";
 import { DataConnectorMetadata } from "./components/deploy/dataConnectorBrowser/DataConnectorBrowser";
 
 export class Global {
@@ -176,9 +176,12 @@ export class Global {
     public static lastBudgetCost: number = 0;
     public static lastDataConnectors: DataConnectorMetadata[] = [];
 
+    public static packagesAccordionExpanded: boolean = false
+    public static filesAccordionExpanded: boolean = false
+
     // We will use these for the steps for fractions
     private static generateFractionSteps = () => {
-        const steps = new LogScaleUtils(0, 1, 0.01, 1, true).getMarks();
+        const steps = new ExpScaleUtils(0, 1, 0.01, 1, true).getMarks();
         steps.unshift(
             {
                 value: -1,
@@ -199,10 +202,8 @@ export class Global {
             }
             throw new ServerConnection.ResponseError(response);
         } else {
-            Global.consecutive401s = 0;
-            if (response.status >= 300) {
-                throw new ServerConnection.ResponseError(response);
-            }
+            if (response.status != 204) Global.consecutive401s = 0;
+            if (response.status >= 300) throw new ServerConnection.ResponseError(response);
         } 
     }
 
