@@ -27,6 +27,7 @@ import { Agreement } from './Agreement';
 import { SnackbarProvider } from 'notistack';
 import { providerOptions } from '../models/Snackbar';
 import { Box } from '@material-ui/core';
+import createSpacing from '@material-ui/core/styles/createSpacing';
 
 const GlobalThemeDiv = withStyles({
 	'@global': {
@@ -43,7 +44,7 @@ const GlobalThemeDiv = withStyles({
 			outline: 'none !important',
 		},
 		'code': {
-			color: 'var(--jp-ui-font-color0) !important',
+			color: 'var(--jp-ui-font-color1) !important',
 		},
 	}
 })(Box)
@@ -140,15 +141,15 @@ class OptumiLeftPanel extends React.Component<IProps, IState> {
 					// dark: will be calculated from palette.error.main,
 				 	// contrastText: will be calculated to contrast with palette.error.main
 				 },
-				 // warning: {
-
-				 // },
+				 warning: {
+					main: '#ffba7d',
+				 },
 				 // info: {
 
 				 // },
 				 success: {
 					 // light: will be calculated from palette.error.main,
-					 main: '#68da7c',
+					 main: '#7cdf8e',
 					 // dark: will be calculated from palette.error.main,
 					 // contrastText: will be calculated to contrast with palette.error.main
 				 },
@@ -160,6 +161,7 @@ class OptumiLeftPanel extends React.Component<IProps, IState> {
 				 // E.g., shift from Red 500 to Red 300 or Red 700.
 				 tonalOffset: 0.2,
 		 	},
+			spacing: createSpacing(12),
 		});
 	}
 	theme: Theme = this.getTheme();
