@@ -12,7 +12,7 @@ import { CSSProperties } from '@material-ui/core/styles/withStyles';
 import CloseIcon from '@material-ui/icons/Close';
 import { Global } from '../Global';
 import { ServerConnection } from '@jupyterlab/services';
-import { AccountConnectorsSubMenu, AccountGeneralSubMenu, AccountLimitsSubMenu, AccountPaymentSubMenu } from './settings/SettingsMenu';
+import { AccountConnectorsSubMenu, AccountFilesSubMenu, AccountGeneralSubMenu, AccountLimitsSubMenu, AccountPaymentSubMenu } from './settings/SettingsMenu';
 import { ShadowedDivider } from '../core';
 import { User } from '../models/User';
 import WarningPopup from '../core/WarningPopup';
@@ -34,6 +34,7 @@ export const enum Page {
     LIMITS = 1,
     PAYMENT = 2,
     CONNECTORS = 3,
+    FILES = 4,
 }
 
 interface IProps {
@@ -257,8 +258,17 @@ export class UserDialog extends React.Component<IProps, IState> {
                     <ShadowedDivider />
                     <div style={{display: 'flex', height: 'calc(100% - 60px - 2px'}}>
                         <div style={{width: '150px'}}>
-                            <DialogContent style={{padding: '0px'}}>
-                                <div style={{padding: '6px'}}>
+                            <DialogContent style={{
+                                overflowY: 'auto',
+                                height: '100%',
+                                padding: '0px',
+                            }}>
+                                <div style={{
+                                    display: 'flex',
+                                    flexDirection: 'column',
+                                    padding: '6px',
+                                    height: '100%',
+                                }}>
                                     <Tabs
                                         value={this.state.selectedPanel}
                                         onChange={(event, newValue) => this.safeSetState({selectedPanel: newValue})}
@@ -266,7 +276,7 @@ export class UserDialog extends React.Component<IProps, IState> {
                                         variant='fullWidth'
                                         indicatorColor='primary'
                                         textColor='primary'
-                                        style={{minHeight: '24px'}}
+                                        style={{minHeight: '24px', flexGrow: 1}}
                                     >
                                         <Tab
                                             label='GENERAL'
@@ -276,7 +286,6 @@ export class UserDialog extends React.Component<IProps, IState> {
                                                 minHeight: '36px',
                                             }}
                                             value={Page.GENERAL}
-                                            
                                         />
                                         <Tab
                                             label='LIMITS'
@@ -305,7 +314,25 @@ export class UserDialog extends React.Component<IProps, IState> {
                                             }}
                                             value={Page.PAYMENT}
                                         />
+                                        {/* <Tab
+                                            label='FILES'
+                                            style={{
+                                                padding: '0px',
+                                                minWidth: 'auto',
+                                                minHeight: '36px',
+                                            }}
+                                            value={Page.FILES}
+                                        /> */}
                                     </Tabs>
+                                    <div style={{
+                                        margin: '12px',
+                                        color: 'var(--jp-ui-font-color3)',
+                                        textAlign: 'center',
+                                        fontSize: '10px',
+                                        fontStyle: 'italic',
+                                    }}>
+                                        Version {Global.version}
+                                    </div>
                                 </div>
                             </DialogContent>
                         </div>
@@ -365,8 +392,10 @@ export class UserDialog extends React.Component<IProps, IState> {
                                         <AccountLimitsSubMenu style={{flexGrow: 1, overflowY: 'auto', maxWidth: '450px'}} />
                                     ) : this.state.selectedPanel == Page.PAYMENT ? (
                                         <AccountPaymentSubMenu style={{flexGrow: 1, overflowY: 'auto', maxWidth: '450px'}} />
-                                    ) : this.state.selectedPanel == Page.CONNECTORS && (
+                                    ) : this.state.selectedPanel == Page.CONNECTORS ? (
                                         <AccountConnectorsSubMenu style={{flexGrow: 1, overflowY: 'auto'}} />
+                                    ) : this.state.selectedPanel == Page.FILES && (
+                                        <AccountFilesSubMenu style={{flexGrow: 1, overflowY: 'auto'}} />
                                     )}
                                 </div>
                             </DialogContent>
