@@ -53,6 +53,7 @@ interface IState {
 
 // TODO:Beck The popup needs to be abstracted out, there is too much going on to reproduce it in more than one file
 export class AddFilesPopup extends React.Component<IProps, IState> {
+    private _isMounted = false
 
     private getSelectedFiles: () => FileMetadata[] = () => []
 
@@ -65,11 +66,11 @@ export class AddFilesPopup extends React.Component<IProps, IState> {
     
     private handleClickOpen = () => {
         if (this.props.onOpen) this.props.onOpen()
-		this.setState({ open: true });
+		this.safeSetState({ open: true });
 	}
 
 	private handleClose = () => {
-        this.setState({ open: false });
+        this.safeSetState({ open: false });
         if (this.props.onClose) this.props.onClose()
     }
     
@@ -86,7 +87,7 @@ export class AddFilesPopup extends React.Component<IProps, IState> {
     }
 
     public render = (): JSX.Element => {
-        if (Global.shouldLogOnRender) console.log('AddFilesPopupRender (' + new Date().getSeconds() + ')');
+        if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <div style={Object.assign({display: 'inline-flex', width: '50%'}, this.props.style)} >
                 <StyledButton
@@ -162,10 +163,34 @@ export class AddFilesPopup extends React.Component<IProps, IState> {
     }
 
     public componentDidMount = () => {
+        this._isMounted = true
         document.addEventListener('keydown', this.handleKeyDown, false)
     }
 
     public componentWillUnmount = () => {
         document.removeEventListener('keydown', this.handleKeyDown, false)
+        this._isMounted = false
     }
+
+    private safeSetState = (map: any) => {
+		if (this._isMounted) {
+			let update = false
+			try {
+				for (const key of Object.keys(map)) {
+					if (JSON.stringify(map[key]) !== JSON.stringify((this.state as any)[key])) {
+						update = true
+						break
+					}
+				}
+			} catch (error) {
+				update = true
+			}
+			if (update) {
+				if (Global.shouldLogOnSafeSetState) console.log('SafeSetState (' + new Date().getSeconds() + ')');
+				this.setState(map)
+			} else {
+				if (Global.shouldLogOnSafeSetState) console.log('SuppressedSetState (' + new Date().getSeconds() + ')');
+			}
+		}
+	}
 }
