@@ -8,7 +8,7 @@
 import * as React from 'react';
 import withStyles, { CSSProperties } from '@material-ui/core/styles/withStyles';
 import { TextBox, SubHeader } from '../../core';
-import { OutlinedInput, IconButton, Accordion, AccordionSummary, AccordionDetails, withTheme, Theme } from '@material-ui/core';
+import { OutlinedInput, IconButton, Accordion, AccordionSummary, AccordionDetails, withTheme, Theme, CircularProgress, Button } from '@material-ui/core';
 import { Global } from '../../Global';
 import { FileUploadConfig } from '../../models/FileUploadConfig';
 import CloseIcon from '@material-ui/icons/Close'
@@ -26,6 +26,10 @@ import { ServerConnection } from '@jupyterlab/services';
 import DataConnectorDirListingItemIcon from './dataConnectorBrowser/DataConnectorDirListingItemIcon';
 import { ExpandMore, WarningRounded } from '@material-ui/icons';
 import { NotificationsPopup } from './NotificationsPopup';
+import ExtraInfo from '../../utils/ExtraInfo';
+import FormatUtils from '../../utils/FormatUtils';
+import { InfoPopup } from '../../core/InfoPoppup';
+// import { EmbeddedYoutube } from '../../core/EmbeddedYoutube';
 
 // const emDirNotFile = 'Path is a directory, not a file'
 // const emDupPath = 'Duplicate file or directory'
@@ -74,6 +78,21 @@ const StyledAccordionDetails = withStyles({
     },
 })(AccordionDetails)
 
+const StyledButton = withStyles({
+    root: {
+        height: '20px',
+        padding: '0px',
+        fontSize: '12px',
+        lineHeight: '12px',
+        minWidth: '0px',
+        margin: '0px 6px 6px 6px',
+        width: '100%',
+    },
+    label: {
+        height: '20px',
+    },
+ })(Button);
+
 interface IProps {
     style?: CSSProperties
     openUserDialogTo?: (page: number) => Promise<void> // This is somewhat spaghetti code-y, maybe think about revising
@@ -85,8 +104,6 @@ interface IState {
     // Here is where we will keep a list of the file paths that were entered successfully but no longer exist on the disk
     problemFiles: string[]
     problemDataConnectors: string[]
-    packagesExpanded: boolean
-    filesExpanded: boolean
 }
 
 class FilesPanel extends React.Component<IProps, IState> {
@@ -106,8 +123,6 @@ class FilesPanel extends React.Component<IProps, IState> {
             filePath: '',
             problemFiles: [],
             problemDataConnectors: [],
-            packagesExpanded: false,
-            filesExpanded: false,
         }
     }
 
@@ -134,11 +149,23 @@ class FilesPanel extends React.Component<IProps, IState> {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
         const uploads: UploadConfig = optumi.config.upload;
-        uploads.requirements = value;
+        uploads.requirements = value.replace(' ', '');
         tracker.setMetadata(optumi);
         return '';
     }
 
+    private autoAddPackages = () => {
+        const tracker: OptumiMetadataTracker = Global.metadata;
+        const optumi = tracker.getMetadata();
+        const uploads: UploadConfig = optumi.config.upload;
+        const requirements = uploads.requirements;
+        const newRequirements = OptumiMetadataTracker.autoAddPackages(requirements, Global.tracker.currentWidget.content.model);
+        if (newRequirements != requirements) {
+            uploads.requirements = newRequirements;
+            tracker.setMetadata(optumi);
+        } 
+    }
+
     private pathHasError = (path: string): boolean => {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
@@ -170,16 +197,42 @@ class FilesPanel extends React.Component<IProps, IState> {
             <div style={this.props.style}>
                 <StyledAccordion
                     variant={'outlined'}
-                    expanded={this.state.packagesExpanded}
+                    expanded={Global.packagesAccordionExpanded}
                     style={{background: 'var(--jp-layout-color1)'}}
                 >
                     <StyledAccordionSummary style={{cursor: 'default'}}>
-                        <SubHeader title='Packages' />
+                        <div style={{display: 'flex'}}>
+                            <SubHeader title='Packages'/>
+                            <InfoPopup
+                                title='Packages'
+                                popup={
+                                    <div style={{margin: '12px'}}>
+                                        <p style={{whiteSpace: 'pre-line'}}>
+                                            {`List python packages that your notebook imports. Optumi will pip install these packages onto the machine your session or job will run on.
+
+                                            Each package should go on a separate line:`}
+                                        </p>
+                                        <img src="https://drive.google.com/uc?export=view&id=1WePvBvaS_6xgvrljKSp8iaijlnD9MFxL" width="350" />
+                                        <p style={{whiteSpace: 'pre-line'}}>
+                                            {`
+                                            To save time you can hit the “Auto-add” button. Optumi will scan your notebook for imported packages and list them for you. However, this is a beta feature and we encourage you to double check that the list is correct.
+                                            `}
+                                        </p>
+                                        {/* <EmbeddedYoutube
+                                            name='Demo'
+                                            url={'https://www.youtube.com/watch?v=MXzv-XL6LLs'}
+                                            width={700}
+                                            height={480}
+                                        /> */}
+                                    </div>
+                                }
+                            />
+                        </div>
                         <span style={{
                             margin: 'auto 15px',
                             flexGrow: 1,
                             textAlign: 'end',
-                            opacity: this.state.packagesExpanded ? 0 : 0.5,
+                            opacity: Global.packagesAccordionExpanded ? 0 : 0.5,
                             transitionDuration: '217ms',
                             whiteSpace: 'nowrap',
                             fontSize: '12px',
@@ -194,14 +247,30 @@ class FilesPanel extends React.Component<IProps, IState> {
                             })()}
                         </span>
                         <IconButton
-                            onClick={() => this.safeSetState({packagesExpanded: !this.state.packagesExpanded})}
-                            style={{padding: '0px', marginRight: '-3px', width: '30px'}}
+                            onClick={() => {
+                                Global.packagesAccordionExpanded = !Global.packagesAccordionExpanded
+                                if (this._isMounted) this.forceUpdate();
+                            }}
+                            style={{padding: '0px', marginRight: '-3px', width: '30px', transform: Global.packagesAccordionExpanded ? 'rotate(180deg)' : undefined}}
                         >
                             <ExpandMore />
                         </IconButton>
                     </StyledAccordionSummary>
                     <StyledAccordionDetails>
-                        <div style={{display: 'flex', width: '100%'}}>
+                        <div style={{width: '100%'}}>
+                            <div style={{width: '100%', display: 'inline-flex'}}>
+                                <div style={{width: '50%', display: 'inline-flex'}}>
+                                    <StyledButton
+                                        onClick={this.autoAddPackages}
+                                        variant='contained'
+                                        disableElevation
+                                        color='primary'
+                                    >
+                                        Auto add
+                                    </StyledButton>
+                                </div>
+                                <div style={{width: '50%', display: 'inline-flex'}} />
+                            </div>
                             <TextBox<string>
                                 key={optumi.upload.requirements}
                                 multiline
@@ -215,17 +284,36 @@ class FilesPanel extends React.Component<IProps, IState> {
                 </StyledAccordion>
                 <StyledAccordion
                     variant={'outlined'}
-                    expanded={this.state.filesExpanded}
+                    expanded={Global.filesAccordionExpanded}
                     style={{background: 'var(--jp-layout-color1)'}}
                 >
                     <StyledAccordionSummary style={{cursor: 'default'}}>
-                        <SubHeader title='Files' />
+                        <div style={{display: 'flex'}}>
+                            <SubHeader title='Files'/>
+                            <InfoPopup
+                                title='Files'
+                                popup={
+                                    <div style={{margin: '12px'}}>
+                                        <p style={{whiteSpace: 'pre-line'}}>
+                                            {`Upload local files and access data from supported databases. Optumi will transfer files to the machine your session or job will run on.`}
+                                        </p>
+                                        <img src="https://drive.google.com/uc?export=view&id=1scH_eNAfnI5ivkEGfq30fjmpOdBWBmII" width="350" />
+                                        {/* <EmbeddedYoutube
+                                            name='Demo'
+                                            url={'https://www.youtube.com/watch?v=MXzv-XL6LLs'}
+                                            width={700}
+                                            height={480}
+                                        /> */}
+                                    </div>
+                                }
+                            />
+                        </div>
                         {(this.state.problemFiles.length > 0 || this.state.problemDataConnectors.length > 0) && <WarningRounded fontSize={'small'} style={{color: this.props.theme.palette.error.main, marginTop: '4px'}} />}
                         <span style={{
                             margin: 'auto 15px',
                             flexGrow: 1,
                             textAlign: 'end',
-                            opacity: this.state.filesExpanded ? 0 : 0.5,
+                            opacity: Global.filesAccordionExpanded ? 0 : 0.5,
                             transitionDuration: '217ms',
                             whiteSpace: 'nowrap',
                             fontSize: '12px',
@@ -234,8 +322,11 @@ class FilesPanel extends React.Component<IProps, IState> {
                             {files.length > 0 && (files.length + ' upload' + (files.length > 1 ? 's' : ''))}{files.length > 0 && dataConnectors.length > 0 ? ', ' : ''}{dataConnectors.length > 0 && (dataConnectors.length + ' connector' + (dataConnectors.length > 1 ? 's' : ''))}
                         </span>
                         <IconButton
-                            onClick={() => this.safeSetState({filesExpanded: !this.state.filesExpanded})}
-                            style={{padding: '0px', marginRight: '-3px', width: '30px'}}
+                            onClick={() => {
+                                Global.filesAccordionExpanded = !Global.filesAccordionExpanded
+                                if (this._isMounted) this.forceUpdate();
+                            }}
+                            style={{padding: '0px', marginRight: '-3px', width: '30px', transform: Global.filesAccordionExpanded ? 'rotate(180deg)' : undefined}}
                         >
                             <ExpandMore />
                         </IconButton>
@@ -265,6 +356,7 @@ class FilesPanel extends React.Component<IProps, IState> {
                                         }))
                                     }
                                     tracker.setMetadata(optumi)
+                                    Global.user.fileTracker.uploadFiles(fileModel)
                                 }
                             }} />
                             <AddDataConnectorsPopup openUserDialogTo={this.props.openUserDialogTo}
@@ -301,6 +393,14 @@ class FilesPanel extends React.Component<IProps, IState> {
                                             key={value.path}
                                             file={value}
                                             handleFileDelete={() => {
+                                                // Cancel the upload
+                                                const progress = Global.user.fileTracker.get(value.path);
+                                                const compression = progress.filter(x => x.type == 'compression');
+                                                const upload = progress.filter(x => x.type == 'upload');
+                                                if (compression.length > 0) compression[0].cancel();
+                                                if (upload.length > 0) upload[0].cancel();
+
+                                                // Remove the file from metadata
                                                 const tracker: OptumiMetadataTracker = Global.metadata;
                                                 const optumi = tracker.getMetadata();
                                                 const files = optumi.config.upload.files
@@ -385,6 +485,7 @@ class FilesPanel extends React.Component<IProps, IState> {
             const files = optumi.upload.files;
             for (var file of files) {
                 if (!this.refreshingFiles) break;
+                Global.user.fileTracker.uploadFiles({ path: file.path, type: file.type } as FileMetadata);
                 if (!this.state.problemFiles.includes(file.path)) {
                     const barr = await FileServerUtils.checkIfPathExists(file.path);
                     if (!barr[0]) {
@@ -502,6 +603,9 @@ class ResourceFile extends React.Component<RFProps, RFState> {
 
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
+        const progress = Global.user.fileTracker.get(this.props.file.path);
+        const compression = progress.filter(x => x.type == 'compression');
+        const upload = progress.filter(x => x.type == 'upload');
         return (
             <div
                 style={{display: 'flex', width: '100%', position: 'relative'}}
@@ -514,7 +618,7 @@ class ResourceFile extends React.Component<RFProps, RFState> {
             >
                 <div style={{
                     position: 'absolute',
-                    right: '-16px',
+                    right: '-10px',
                     display: 'inline-flex',
                     background: 'var(--jp-layout-color1)',
                     opacity: this.state.hovering ? '1' : '0',
@@ -538,11 +642,25 @@ class ResourceFile extends React.Component<RFProps, RFState> {
                         padding: '3px 6px 3px 6px',
                         display: 'inline-flex'
                     }}
-                >   
-                    <DirListingItemIcon
-                        fileType={this.props.file.type}
-                        mimetype={this.props.file.mimetype}
-                    />
+                >
+                    {(compression.length > 0 || (upload.length > 0 && upload[0].total < 0)) ? (
+                        <ExtraInfo reminder={compression.length > 0 ? compression[0].total == -1 ? '' : 'Compressed ' + compression[0].progress + '/' + compression[0].total + ' files' : ''}>
+                            <div style={{height: '16px', width: '16px', marginRight: '4px'}}>
+                                <CircularProgress color="primary" size='14px' thickness={8} style={{margin: 'auto'}}/>
+                            </div>
+                        </ExtraInfo>
+                    ) : (upload.length > 0 ? (
+                        <ExtraInfo reminder={FormatUtils.styleCapacityUnitValue()(upload[0].progress) + '/' + FormatUtils.styleCapacityUnitValue()(upload[0].total)}>
+                            <div style={{height: '16px', width: '16px', marginRight: '4px'}}>
+                                <CircularProgress variant="determinate" size='14px' thickness={8} style={{margin: 'auto'}} value={(upload[0].progress / upload[0].total) * 100 } />
+                            </div>
+                        </ExtraInfo>
+                    ) : (
+                        <DirListingItemIcon
+                            fileType={this.props.file.type}
+                            mimetype={this.props.file.mimetype}
+                        />
+                    ))}
                     <div
                         style={{
                             margin: 'auto 0px',
@@ -572,11 +690,15 @@ Path: ${this.props.file.path.replace(/\/[^\/]*$/, '')}`
         )
     }
 
+    private handleFilesChanged = () => this.forceUpdate();
+
     public componentDidMount = () => {
         this._isMounted = true
+        Global.user.fileTracker.getFilesChanged().connect(this.handleFilesChanged)
     }
 
     public componentWillUnmount = () => {
+        Global.user.fileTracker.getFilesChanged().disconnect(this.handleFilesChanged)
         this._isMounted = false
     }
 
@@ -648,7 +770,7 @@ class ResourceDataConnector extends React.Component<RDCProps, RDCState> {
             >
                 <div style={{
                     position: 'absolute',
-                    right: '-16px',
+                    right: '-10px',
                     display: 'inline-flex',
                     background: 'var(--jp-layout-color1)',
                     opacity: this.state.hovering ? '1' : '0',
