@@ -8,8 +8,6 @@
 import * as React from 'react';
 import { Global } from '../../Global';
 
-import { ServerConnection } from '@jupyterlab/services';
-
 import {
 	ListItem,
 	IconButton,
@@ -18,25 +16,22 @@ import {
 
 import GetAppIcon from '@material-ui/icons/GetApp';
 import DoneIcon from '@material-ui/icons/Done';
+import { FileMetadata } from './fileBrowser/FileBrowser';
 
 // Properties from parent
 interface IProps {
 	workloadUUID: string;
     moduleUUID: string;
     name: string;
-	lastModified: string;
-	size: number;
-	files: string[];
+	files: FileMetadata[];
     disabled: boolean;
     overwrite: boolean;
 }
 
 // Properties for this component
 interface IState {
-	loaded: number;
-    total: number;
-    downloading: boolean;
-	downloaded: boolean;
+	downloading: boolean
+	downloaded: boolean
 }
 
 export class OutputFileEntry extends React.Component<IProps, IState> {
@@ -46,77 +41,13 @@ export class OutputFileEntry extends React.Component<IProps, IState> {
 	constructor(props: IProps) {
 		super(props);
 		this.state = {
-			loaded: 0,
-            total: 0,
-            downloading: false,
+			downloading: false,
 			downloaded: false,
 		};
 	}
 
-	private getDownloadProgress(name: string) {
-		const settings = ServerConnection.makeSettings();
-		const url = settings.baseUrl + "optumi/get-file-download-progress";
-		const init: RequestInit = {
-			method: 'POST',
-			body: JSON.stringify({
-				// The key we use to watch download progress
-                name: name,
-			}),
-		};
-		ServerConnection.makeRequest(
-			url,
-			init, 
-			settings
-		).then((response: Response) => {
-			Global.handleResponse(response);
-			if (response.status == 204) {
-				if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
-				setTimeout(() => this.getDownloadProgress(name), 500);
-				return;
-			}
-			return response.json();
-		}).then((body: any) => {
-			if (body) {
-				this.safeSetState({ loaded: body.read, total: body.total });
-				if (!(body.read != 0 && body.read == body.total)) {
-					if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
-					setTimeout(() => this.getDownloadProgress(name), 500);
-				}
-			}
-		}, (error: ServerConnection.ResponseError) => {
-			if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
-			setTimeout(() => this.getDownloadProgress(name), 500);
-		});
-	}
-
-	public async saveOutputFile(name: string, files: string[]) {
-		const settings = ServerConnection.makeSettings();
-		const url = settings.baseUrl + "optumi/save-notebook-output-file";
-		const init = {
-			method: 'POST',
-			body: JSON.stringify({
-				workloadUUID: this.props.workloadUUID,
-				moduleUUID: this.props.moduleUUID,
-				name: name,
-                files: files,
-                overwrite: this.props.overwrite,
-			}),
-		};
-		ServerConnection.makeRequest(
-			url,
-			init, 
-			settings
-		).then((response: Response) => {
-			Global.handleResponse(response);
-			return response.text();
-		}).then((body: string) => {
-			this.safeSetState({ downloaded: true, downloading: false })
-			setTimeout(() => this.safeSetState({ downloaded: false }), 5000);
-		});
-		this.getDownloadProgress(name);
-	}
-
 	private formatSize = (value: number) => {
+		if (value == 0) return "";
 		if (value < Math.pow(1024, 1)) {
             return value.toFixed() + ' B';
         } else if (value < Math.pow(1024, 2)) {
@@ -133,8 +64,8 @@ export class OutputFileEntry extends React.Component<IProps, IState> {
 	}
 
 	private formatExtraInfo = () => {
-		var lastModified = this.props.lastModified == "" ? "" : new Date(this.props.lastModified).toLocaleTimeString();
-		var size = this.props.size == 0 ? "" : this.formatSize(this.props.size);
+		var lastModified = this.props.files.length > 1 || this.props.files[0].last_modified == undefined ? "" : new Date(this.props.files[0].last_modified).toLocaleTimeString();
+		var size = this.formatSize(this.props.files.reduce((a, b) => { return { size: a.size + b.size } }, {size: 0}).size);
 		if (lastModified == "" && size == "") return "";
 		if (lastModified == "") return " (" + size + ")";
 		if (size == "") return " (" + lastModified + ")";
@@ -144,6 +75,8 @@ export class OutputFileEntry extends React.Component<IProps, IState> {
 	// The contents of the component
 	public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
+		const progress = Global.user.fileTracker.get(this.props.name);
+        const download = progress.filter(x => x.type == 'download');
 		return (
             <ListItem style={{paddingTop: "2px", paddingBottom: "2px"}}>
 				{ this.state.downloaded ? (
@@ -155,32 +88,32 @@ export class OutputFileEntry extends React.Component<IProps, IState> {
 					</IconButton>
 				) : (
 					<div>
-						{!this.state.downloading ? (
+						{download.length > 0 ? (
+							<div style={{position: 'relative', height: '48px', width: '48px'}}>
+							<CircularProgress />
+							<span style={{position: 'absolute', top: '12.5px', left: '9px', fontSize: '0.75rem'}}>
+								{((download[0].progress/download[0].total) * 100).toFixed(0) + "%"}
+							</span>
+						</div>
+						) : (
 							<IconButton
 								edge="end"
 								disabled={this.props.disabled}
 								onClick={ () => {
-										this.saveOutputFile(this.props.name, this.props.files);
+										Global.user.fileTracker.downloadFiles(this.props.name, this.props.files, this.props.workloadUUID, this.props.moduleUUID, this.props.overwrite);
 										this.safeSetState({ downloading: true });
 									}
 								}
 							>
 								<GetAppIcon />
 							</IconButton>
-						) : (
-							<div style={{position: 'relative', height: '48px', width: '48px'}}>
-								<CircularProgress />
-                                <span style={{position: 'absolute', top: '12.5px', left: '9px', fontSize: '0.75rem'}}>
-									{this.state.loaded != this.state.total ? ((this.state.loaded/this.state.total) * 100).toFixed(0) + "%" : ''}
-								</span>
-							</div>
 						)}
 					</div>
 				)}
                 <div
 					style={{
 						overflow: 'auto',
-						marginLeft: !this.state.downloading ? '24px' : '12px',
+						marginLeft: download.length > 0 ? '24px' : '12px',
 						marginTop: '4px',
 						marginBottom: '4px',
 						opacity: this.props.disabled ? '0.5' : '1',
@@ -192,8 +125,14 @@ export class OutputFileEntry extends React.Component<IProps, IState> {
 		);
 	}
 
-	private update() {
+	private update = () => {
 		if (this._isMounted) {
+			const progress = Global.user.fileTracker.get(this.props.name);
+        	const download = progress.filter(x => x.type == 'download');
+			if (this.state.downloading && download.length == 0) {
+				this.safeSetState({ downloading: false, downloaded: true });
+				setTimeout(() => this.safeSetState({ downloaded: false }) , 5000);
+			}
 			this.forceUpdate();
 		}
 	}
@@ -201,11 +140,13 @@ export class OutputFileEntry extends React.Component<IProps, IState> {
 	// Will be called automatically when the component is mounted
 	public componentDidMount = () => {
 		this._isMounted = true;
+		Global.user.fileTracker.getFilesChanged().connect(this.update)
 		this.update();
 	}
 
 	// Will be called automatically when the component is unmounted
 	public componentWillUnmount = () => {
+		Global.user.fileTracker.getFilesChanged().disconnect(this.update)
 		this._isMounted = false;
 	}
 
