@@ -8,7 +8,7 @@
 import * as React from 'react';
 import { Global } from '../../../Global';
 
-import { GraphicsMetadata } from '../../../models/GraphicsMetadata';
+import { GraphicsConfig } from '../../../models/GraphicsConfig';
 import { Switch } from '../../../core';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 
@@ -23,14 +23,14 @@ export class GraphicsBasic extends React.Component<IProps, IState> {
     private getValue(): boolean {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-		const graphics: GraphicsMetadata = optumi.metadata.graphics;
+		const graphics: GraphicsConfig = optumi.config.graphics;
 		return graphics.required;
 	}
 
 	private async saveValue(checked: boolean) {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-        const graphics: GraphicsMetadata = optumi.metadata.graphics;
+        const graphics: GraphicsConfig = optumi.config.graphics;
         graphics.required = checked;
         tracker.setMetadata(optumi);
 	}
