@@ -15,7 +15,7 @@ import { ChangePasswordPopup } from './ChangePasswordPopup';
 import { CheckoutForm } from './CheckoutForm';
 import { Header, Switch, TextBox, TextBoxDropdown } from '../../core';
 import FormatUtils from '../../utils/FormatUtils';
-import { Button, Divider } from '@material-ui/core';
+import { Button, Divider, IconButton } from '@material-ui/core';
 import GetAppIcon from '@material-ui/icons/GetApp';
 import DataConnectorBrowser, { DataConnectorMetadata } from '../deploy/dataConnectorBrowser/DataConnectorBrowser';
 import { AmazonS3ConnectorPopup } from '../deploy/AmazonS3ConnectorPopup';
@@ -24,6 +24,9 @@ import { GoogleDriveConnectorPopup } from '../deploy/GoogleDriveConnectorPopup';
 import { KaggleConnectorPopup } from '../deploy/KaggleConnectorPopup';
 import { WasabiConnectorPopup } from '../deploy/WasabiConnectorPopup';
 import { PhoneTextBox } from '../../core/PhoneTextBox';
+import { AzureBlobStorageConnectorPopup } from '../deploy/AzureBlobStorageConnector';
+import DeleteIcon from '@material-ui/icons/Delete';
+import ExtraInfo from '../../utils/ExtraInfo';
 
 // Properties from parent
 interface IProps {
@@ -94,14 +97,23 @@ export class AccountGeneralSubMenu extends React.Component<IProps, IAccountGener
                         getValue={() => Global.user.notificationsEnabled }
                         saveValue={(notificationsEnabled: boolean) => { Global.user.notificationsEnabled = notificationsEnabled }}
                         label='Enable SMS notifications to the listed phone number'
-                        labelWidth={LABEL_WIDTH}
                         disabled={Global.user.phoneNumber == ''}
+                        labelBefore
+                        flip
                     />
                     <Switch
                         getValue={() => Global.user.compressFilesEnabled}
                         saveValue={(compressFilesEnabled: boolean) => { Global.user.compressFilesEnabled = compressFilesEnabled }}
                         label='Compress my files before uploading'
-                        labelWidth={LABEL_WIDTH}
+                        labelBefore
+                        flip
+                    />
+                    <Switch
+                        getValue={() => Global.user.snapToInventoryEnabled}
+                        saveValue={(snapToInventoryEnabled: boolean) => { Global.user.snapToInventoryEnabled = snapToInventoryEnabled }}
+                        label='Snap resource selection sliders to existing inventory'
+                        labelBefore
+                        flip
                     />
                 </div>
             </>
@@ -554,6 +566,7 @@ export class AccountConnectorsSubMenu extends React.Component<IProps, IAccountCo
                     <Divider />
                     <div style={{marginBottom: '6px'}} />
                     <AmazonS3ConnectorPopup onClose={this.forceNewBrowser} />
+                    <AzureBlobStorageConnectorPopup onClose={this.forceNewBrowser} />
                     <GoogleCloudStorageConnectorPopup onClose={this.forceNewBrowser} />
                     <GoogleDriveConnectorPopup onClose={this.forceNewBrowser} />
                     <KaggleConnectorPopup onClose={this.forceNewBrowser} />
@@ -606,6 +619,143 @@ export class AccountConnectorsSubMenu extends React.Component<IProps, IAccountCo
     }
 }
 
+
+interface IAccountFilesSubMenuState {
+    files: string[];
+}
+
+export class AccountFilesSubMenu extends React.Component<IProps, IAccountFilesSubMenuState> {
+    private _isMounted = false;
+    private polling = false;
+
+    constructor(props: IProps) {
+        super(props);
+        this.state = {
+            files: [],
+        }
+    }
+
+    public render = (): JSX.Element => {
+		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
+        return (
+            <>
+                <div style={Object.assign({padding: '20px 6px 6px 20px'}, this.props.style)}>
+                    <div>
+                        Listed files are securely stored in the Optumi platform. If you want to delete a file hit its associated trash can icon.
+                    </div>
+                    {this.state.files.map(x => (
+
+                        <div style={{display: 'inline-flex', width: '100%'}}>
+                            <ExtraInfo reminder={x}>
+                                <div style={{margin: 'auto'}}>
+                                    {x.split('/').pop()}
+                                </div>
+                            </ExtraInfo>
+                            <div style={{flexGrow: 1}}/>
+                            <IconButton
+                                onClick={() => this.deleteFile(x)}
+                                style={{position: 'relative', display: 'inline-block', width: '36px', height: '36px', padding: '3px'}}
+                            >
+                                <DeleteIcon style={{position: 'relative', width: '30px', height: '30px', padding: '3px'}} />
+                            </IconButton>
+                        </div>
+                    ))}
+                </div>
+            </>
+        )
+    }
+
+    private async deleteFile(filePath: string) {
+		const settings = ServerConnection.makeSettings();
+        const url = settings.baseUrl + "optumi/delete-files";
+		const init: RequestInit = {
+			method: 'POST',
+			body: JSON.stringify({
+                filePaths: [filePath],
+            }),
+		};
+		ServerConnection.makeRequest(
+			url,
+			init, 
+			settings
+		).then((response: Response) => {
+			Global.handleResponse(response);
+			return response.json();
+		});
+        this.safeSetState({ files: this.state.files.filter(x => x != filePath) });
+    }
+
+    private async receiveUpdate() {
+		const settings = ServerConnection.makeSettings();
+        const url = settings.baseUrl + "optumi/list-files";
+		const init: RequestInit = {
+			method: 'GET',
+		};
+		ServerConnection.makeRequest(
+			url,
+			init, 
+			settings
+		).then((response: Response) => {
+			if (this.polling) {
+				// If we are polling, send a new request in 2 seconds
+                if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
+				setTimeout(() => this.receiveUpdate(), 30000);
+			}
+			Global.handleResponse(response);
+			return response.json();
+		}).then((body: any) => {
+			if (body) {
+                this.safeSetState({ files: body.files });
+			}
+        });
+    }
+
+    // Will be called automatically when the component is mounted
+	public componentDidMount = () => {
+        this._isMounted = true;
+        this.polling = true;
+        this.receiveUpdate();
+	}
+
+	// Will be called automatically when the component is unmounted
+	public componentWillUnmount = () => {
+        this._isMounted = false;
+        this.polling = false;
+    }
+    
+    private safeSetState = (map: any) => {
+		if (this._isMounted) {
+			let update = false
+			try {
+				for (const key of Object.keys(map)) {
+					if (JSON.stringify(map[key]) !== JSON.stringify((this.state as any)[key])) {
+						update = true
+						break
+					}
+				}
+			} catch (error) {
+				update = true
+			}
+			if (update) {
+				if (Global.shouldLogOnSafeSetState) console.log('SafeSetState (' + new Date().getSeconds() + ')');
+				this.setState(map)
+			} else {
+				if (Global.shouldLogOnSafeSetState) console.log('SuppressedSetState (' + new Date().getSeconds() + ')');
+			}
+		}
+	}
+
+    public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
+        try {
+            if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
+            if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
+            if (Global.shouldLogOnRender) console.log('SuppressedRender (' + new Date().getSeconds() + ')');
+            return false;
+        } catch (error) {
+            return true;
+        }
+    }
+}
 export class TeamSubMenu extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
