@@ -49,7 +49,6 @@ interface IProps {
     onClose?: () => any
     style?: CSSProperties
     dataService: DataService
-    iconClass: string
     description: string
     header: string
     downloadPath: string
@@ -167,7 +166,6 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
         return (
             <div style={Object.assign({}, this.props.style)}>
                 <DataConnectorIdentity
-                    iconClass={this.props.iconClass}
                     dataService={this.props.dataService}
                     description={this.props.description}
                     handleClick={this.handleClickOpen}
@@ -194,7 +192,6 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
                             marginLeft: '-6px', // this is to counteract the padding in CreateDataConnector so we can reuse it without messing with it
                         }}>
                             <DataConnectorIdentity
-                                iconClass={this.props.iconClass}
                                 dataService={this.props.dataService}
                                 style={{ zoom: 1.4 }}
                             />
