@@ -8,8 +8,8 @@
 import { ServerConnection } from '@jupyterlab/services';
 import { Global } from '../Global';
 import { Update } from './Update';
-import { OutputFile } from './OutputFile';
 import { Machine } from './machine/Machine';
+import { FileMetadata } from '../components/deploy/fileBrowser/FileBrowser';
 
 export enum Status {
 	INITIALIZING,
@@ -36,10 +36,10 @@ export class Module {
     private _machine: Machine;
     
     private _output: Update[];
-    private _files: OutputFile[];
+    private _files: FileMetadata[];
     private _updates: Update[];
 
-	constructor(uuid: string, machine: Machine = null, sessionToken: string = null, output: Update[] = [], updates: Update[] = [], files: OutputFile[] = [], lastPatch: number = 0) {
+	constructor(uuid: string, machine: Machine = null, sessionToken: string = null, output: Update[] = [], updates: Update[] = [], files: FileMetadata[] = [], lastPatch: number = 0) {
 		this._uuid = uuid;
 
 		this._sessionToken = sessionToken;
@@ -87,7 +87,7 @@ export class Module {
         return this._output;
     }
 
-	get files(): OutputFile[] {
+	get files(): FileMetadata[] {
 		return this._files;
 	}
 
@@ -113,7 +113,7 @@ export class Module {
 				this._output.push(new Update(body.output[i], body.outputmod[i]));
 				if (body.output[i].includes('Jupyter Server ') && body.output[i].includes(' is running at:')) {
 					this._sessionReady = true;
-					window.open('http://localhost:' + this._sessionPort + '?token=' + this._sessionToken, '_blank');
+					window.open('http://' + window.location.hostname + ':' + this._sessionPort + '?token=' + this._sessionToken, '_blank');
 				}
 			}
 		}
@@ -140,12 +140,19 @@ export class Module {
 				}
 			}
 		}
+		// new OutputFile(body.files[i], , body.filessize[i]))
 		if (body.files != null) {
 			this._files = [];
 			for (let i = 0; i < body.files.length; i++) {
 				if (body.files[i] != '') {
 					updated = true
-					this._files.push(new OutputFile(body.files[i], body.filesmod[i], body.filessize[i]));
+					this._files.push({
+						last_modified: body.filesmod[i],
+						name: (body.files[i] as string).split('/').pop(),
+						path: body.files[i],
+						size: +body.filessize[i],
+						type: 'file',
+					} as FileMetadata);
 				}
 			}
 		}
