@@ -79,12 +79,13 @@ export class OptumiConfig {
 			case "3.5.1":
 			case "3.6.0":
 			case "3.7.0":
+			case "3.7.1":
 				break;
 			default:
 				if (!version.includes("DEV")) console.log("Unknown map version: " + version);
         }
         
-        this.intent = (map.intent != undefined ? map.intent : ((user) ? user.intent : 0));
+        this.intent = (map.intent != undefined ? map.intent : ((user) ? user.intent : 0.5));
 		this.compute = new ComputeConfig(map.compute || {}, user);
 		this.graphics = new GraphicsConfig(map.graphics || {}, user); 
         this.memory = new MemoryConfig(map.memory || {}, user);
