@@ -15,6 +15,7 @@ import { Machines } from './Machines';
 import { Machine } from './machine/Machine';
 import { Page } from '../components/deploy/RequirementsBar';
 import { Global } from '../Global';
+import { FileTracker } from './FileTracker';
 
 export class User {
 	
@@ -58,7 +59,9 @@ export class User {
 			responseData.noFileUploadsPreventEnabled,
 			responseData.startSessionPreventEnabled,
 			responseData.notificationsEnabled,
+			responseData.snapToInventoryEnabled,
             new AppTracker(),
+			new FileTracker(),
             new Machines(machines, responseData.maxRate)
         );
         if (!newUser.unsignedAgreement) newUser.synchronize(responseData);
@@ -77,6 +80,12 @@ export class User {
 		return this._selectedSettingsSubMenuChanged;
 	}
 
+	private _userInformationChanged = new Signal<this, User>(this);
+
+	get userInformationChanged(): ISignal<this, User> {
+		return this._userInformationChanged;
+	}
+
     private _unsignedAgreement: boolean;
 
 	private _name: string;
@@ -111,8 +120,10 @@ export class User {
 	private _noFileUploadsPreventEnabled: boolean;
 	private _startSessionPreventEnabled: boolean;
 	private _notificationsEnabled: boolean;
+	private _snapToInventoryEnabled: boolean;
 
 	private _appTracker: AppTracker;
+	private _fileTracker: FileTracker;
 	private _machines: Machines;
 
 	private _deploySubMenu: Page = Page.RESOURCES;
@@ -127,8 +138,8 @@ export class User {
         maxMachines: number, machinesCap: number, 
 		userExpertise: number, proactiveUploadsEnabled: boolean, compressFilesEnabled: boolean, lastPage: number, 
 		stopJobPreventEnabled: boolean, deleteJobPreventEnabled: boolean, noRequirementsPreventEnabled: boolean, noFileUploadsPreventEnabled: boolean, 
-		startSessionPreventEnabled: boolean, notificationsEnabled: boolean,
-		appTracker: AppTracker, machines: Machines) {
+		startSessionPreventEnabled: boolean, notificationsEnabled: boolean, snapToInventoryEnabled: boolean,
+		appTracker: AppTracker, fileTracker: FileTracker, machines: Machines) {
         this._unsignedAgreement = unsignedAgreement === undefined ? true : unsignedAgreement;
         this._name = name;
         this._phoneNumber = phoneNumber;
@@ -163,8 +174,10 @@ export class User {
 		this._noFileUploadsPreventEnabled = noFileUploadsPreventEnabled;
 		this._startSessionPreventEnabled = startSessionPreventEnabled;
 		this._notificationsEnabled = notificationsEnabled;
+		this._snapToInventoryEnabled = snapToInventoryEnabled;
 
 		this._appTracker = appTracker;
+		this._fileTracker = fileTracker;
         this._machines = machines;
     }
     
@@ -517,6 +530,22 @@ export class User {
 		this.setUserInformation("notificationsEnabled", notificationsEnabled.toString());
 	}
 
+	get snapToInventoryEnabled(): boolean {
+		return this._snapToInventoryEnabled;
+	}
+
+	set snapToInventoryEnabled(snapToInventoryEnabled: boolean) {
+		if (snapToInventoryEnabled === this._snapToInventoryEnabled) {
+			return;
+		}
+		this._snapToInventoryEnabled = snapToInventoryEnabled;
+		this.setUserInformation("snapToInventoryEnabled", snapToInventoryEnabled.toString());
+	}
+
+	get fileTracker(): FileTracker {
+		return this._fileTracker;
+	}
+
 	get appTracker(): AppTracker {
 		return this._appTracker;
 	}
@@ -571,7 +600,8 @@ export class User {
 			settings
 		).then((response: Response) => {
 			Global.handleResponse(response);
-		});	
+		});
+		this._userInformationChanged.emit(this);
 	}
 
 	public changePassword(loginName: string, oldPassword: string, newPassword: string) {
