@@ -21,10 +21,8 @@ import { Machine, NoMachine } from '../machine/Machine';
 import { Global } from '../../Global';
 
 import { Update } from '../Update';
-import { OutputFile } from '../OutputFile';
 import { Snackbar } from '../Snackbar';
 import FileServerUtils from '../../utils/FileServerUtils';
-import FormatUtils from '../../utils/FormatUtils';
 
 import { IdentityAppComponent } from './IdentityAppComponent';
 import { AppComponent } from './AppComponent';
@@ -32,11 +30,11 @@ import { PopupAppComponent } from './PopupAppComponent';
 
 import { applyPatch } from 'rfc6902';
 import { NotebookModel } from '@jupyterlab/notebook';
+import { FileMetadata } from '../../components/deploy/fileBrowser/FileBrowser';
 
 export enum Phase {
 	Initializing = 'initializing',
-	Uploading = 'uploading',
-	Requisitioning = 'requisitioning',
+	Preparing = 'preparing',
 	Running = 'running',
 }
 
@@ -63,15 +61,14 @@ export class App {
 	private _modules: Module[] = [];
 
 	private _initializing: ProgressMessage;
-	private _uploading: ProgressMessage;
-	private _requisitioning: ProgressMessage;
+	private _preparing: ProgressMessage;
 	private _running: ProgressMessage;
 
 	private _timestamp: Date;
 	private _runNum: number;
 
 	constructor(path: string, notebook: any = {}, config: OptumiConfig = new OptumiConfig(), uuid: string = "",
-		initializing: Update[] = [], uploading: Update[] = [], requisitioning: Update[] = [], running: Update[] = [], timestamp = new Date(), runNum: number = 0) {		
+		initializing: Update[] = [], preparing: Update[] = [], running: Update[] = [], timestamp = new Date(), runNum: number = 0) {		
 
 		this._notebook = notebook;
 		this._config = config.copy();
@@ -80,14 +77,12 @@ export class App {
 		this._uuid = uuid;
 
 		this._initializing = new ProgressMessage(Phase.Initializing, initializing);
-		this._uploading = new ProgressMessage(Phase.Uploading, uploading);
-		this._requisitioning = new ProgressMessage(Phase.Requisitioning, requisitioning);
+		this._preparing = new ProgressMessage(Phase.Preparing, preparing);
 		this._running = new ProgressMessage(Phase.Running, running);
 		
 		if (this._uuid != "") {
 			this._initializing.appUUID = this._uuid;
-			this._uploading.appUUID = this._uuid;
-			this._requisitioning.appUUID = this._uuid;
+			this._preparing.appUUID = this._uuid;
 			this._running.appUUID = this._uuid;
 		}
 
@@ -96,55 +91,19 @@ export class App {
 
 		// Handle errors where we were unable to load some of the updates
 		if (this._running.started) {
-			if (!this._requisitioning.completed) {
-				this._requisitioning.addUpdate(new Update("Unable to retrieve requisitioning updates", ""));
-				this._requisitioning.addUpdate(new Update("stop", ""));
-			}
-			if (!this._uploading.completed) {
-				this._uploading.addUpdate(new Update("Unable to retrieve uploading updates", ""));
-				this._uploading.addUpdate(new Update("stop", ""));
+			if (!this._preparing.completed) {
+				this._preparing.addUpdate(new Update("Unable to retrieve preparing updates", ""));
+				this._preparing.addUpdate(new Update("stop", ""));
 			}
 			if (!this._initializing.completed) {
 				this._initializing.addUpdate(new Update("Unable to retrieve initializing updates", ""));
 				this._initializing.addUpdate(new Update("stop", ""));
 			}
-		} else if (this._requisitioning.started) {
-			if (!this._uploading.completed) {
-				this._uploading.addUpdate(new Update("Unable to retrieve uploading updates", ""));
-				this._uploading.addUpdate(new Update("stop", ""));
-			}
+		} else if (this._preparing.started) {
 			if (!this._initializing.completed) {
 				this._initializing.addUpdate(new Update("Unable to retrieve initializing updates", ""));
 				this._initializing.addUpdate(new Update("stop", ""));
 			}
-		} else if (this._uploading.started) {
-			if (!this._initializing.completed) {
-				this._initializing.addUpdate(new Update("Unable to retrieve initializing updates", ""));
-				this._initializing.addUpdate(new Update("stop", ""));
-			}
-		}
-
-		// Handle some errors with requests failing while we get an application up and running
-		if (initializing != null) {
-			if (this._initializing.started && !this._initializing.completed) {
-				if (this._initializing.message == "Compressing files") this._initializing.total = -1;
-				this.getCompressionProgress();
-				return;
-			}
-		}
-
-		if (uploading != null) {
-			if (this._uploading.started && !this._uploading.completed) {
-				this.getUploadProgress();
-				return;
-			}
-		}
-
-		if (requisitioning != null) {
-			if (this._requisitioning.started && !this._requisitioning.completed) {
-				if (this._requisitioning.message == "Waiting for cloud provider") this._requisitioning.total = -1;
-				return;
-			}
 		}
 	}
 
@@ -155,19 +114,15 @@ export class App {
         for (let i = 0; i < appMap.initializing.length; i++) {
             initializing.push(new Update(appMap.initializing[i], appMap.initializingmod[i]));
         }
-        const uploading: Update[] = [];
-        for (let i = 0; i < appMap.uploading.length; i++) {
-            uploading.push(new Update(appMap.uploading[i], appMap.uploadingmod[i]));
-        }
-        const requisitioning: Update[] = [];
-        for (let i = 0; i < appMap.requisitioning.length; i++) {
-            requisitioning.push(new Update(appMap.requisitioning[i], appMap.requisitioningmod[i]));
+        const preparing: Update[] = [];
+        for (let i = 0; i < appMap.preparing.length; i++) {
+            preparing.push(new Update(appMap.preparing[i], appMap.preparingmod[i]));
         }
         const running: Update[] = [];
         for (let i = 0; i < appMap.running.length; i++) {
             running.push(new Update(appMap.running[i], appMap.runningmod[i]));
         }
-		var app: App = new App(appMap.name, JSON.parse(appMap.notebook), new OptumiConfig(JSON.parse(appMap.nbConfig)), appMap.uuid, initializing, uploading, requisitioning, running, new Date(appMap.timestamp), appMap.runNum);
+		var app: App = new App(appMap.name, JSON.parse(appMap.notebook), new OptumiConfig(JSON.parse(appMap.nbConfig)), appMap.uuid, initializing, preparing, running, new Date(appMap.timestamp), appMap.runNum);
 		// Add modules
 		for (let module of appMap.modules) {
             const output: Update[] = [];
@@ -178,10 +133,16 @@ export class App {
             for (let i = 0; i < module.updates.length; i++) {
 				updates.push(new Update(module.updates[i], module.updatesmod[i]));
             }
-            const files: OutputFile[] = [];
+            const files: FileMetadata[] = [];
             for (let i = 0; i < module.files.length; i++) {
                 if (module.files[i] != '') {
-                    files.push(new OutputFile(module.files[i], module.filesmod[i], module.filessize[i]));
+                    files.push({
+						last_modified: module.filesmod[i],
+						name: (module.files[i] as string).split('/').pop(),
+						path: module.files[i],
+						size: +module.filessize[i],
+						type: 'file',
+					} as FileMetadata);
                 }
 			}
 			var lastPatch: number = 0;
@@ -213,7 +174,7 @@ export class App {
 			app._modules.push(mod);
 			if (mod.modStatus == Status.RUNNING) {
                 // The module is still running
-                if (!app._initializing.completed || !app._uploading.completed || !app._requisitioning.completed || !app._running.completed) {
+                if (!app._initializing.completed || !app._preparing.completed || !app._running.completed) {
 					if (app.interactive) mod.startSessionHandler();
                 }
 			}
@@ -229,30 +190,18 @@ export class App {
 				this._initializing.addUpdate(new Update(body.initializing[i], body.initializingmod[i]), false);
 			}
 		}
-		if (body.uploading != null) {
-			if (body.uploading.length > 0) updated = true;
-			for (let i = 0; i < body.uploading.length; i++) {
-				this._uploading.addUpdate(new Update(body.uploading[i], body.uploadingmod[i]), false);
-			}
-		}
-		if (body.requisitioning != null) {
-			if (body.requisitioning.length > 0) updated = true;
-			for (let i = 0; i < body.requisitioning.length; i++) {
-				this._requisitioning.addUpdate(new Update(body.requisitioning[i], body.requisitioningmod[i]), false);
+		if (body.preparing != null) {
+			if (body.preparing.length > 0) updated = true;
+			for (let i = 0; i < body.preparing.length; i++) {
+				this._preparing.addUpdate(new Update(body.preparing[i], body.preparingmod[i]), false);
 				// Special case a warning when we fail to get a machine and start trying a new one
-				if ((body.requisitioning[i] as string).startsWith('Machine unavailable, trying another')) {
+				if ((body.preparing[i] as string).startsWith('Machine unavailable, trying another')) {
 					if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
 					Global.snackbarChange.emit(new Snackbar(
-						this.name + " (" +  this.annotationOrRunNum + "): " + body.requisitioning[i],
+						this.name + " (" +  this.annotationOrRunNum + "): " + body.preparing[i],
 						{ variant: 'warning', }
 					));
 				}
-				// Special case loading bar while waiting for a server
-				if (this._requisitioning.message == "Waiting for cloud provider") {
-					this._requisitioning.total = -1;
-				} else {
-					this._requisitioning.total = 0;
-				}
 			}
 		}
 		if (body.running != null) {
@@ -353,12 +302,8 @@ export class App {
 		return this._initializing;
 	}
 
-	get uploading(): ProgressMessage {
-		return this._uploading;
-	}
-
-	get requisitioning(): ProgressMessage {
-		return this._requisitioning;
+	get preparing(): ProgressMessage {
+		return this._preparing;
 	}
 
 	get running(): ProgressMessage {
@@ -377,7 +322,7 @@ export class App {
 		for (let mod of this.modules) {
 			if (mod.error) return true;
 		}
-		return this._initializing.error || this._uploading.error || this._requisitioning.error || this._running.error;
+		return this._initializing.error || this._preparing.error || this._running.error;
 	}
 
 	get interactive(): boolean {
@@ -485,8 +430,7 @@ export class App {
 			this._uuid = body.uuid;
 			this._runNum = body.runNum;
 			this._initializing.appUUID = this._uuid;
-			this._uploading.appUUID = this._uuid;
-			this._requisitioning.appUUID = this._uuid;
+			this._preparing.appUUID = this._uuid;
 			this._running.appUUID = this._uuid;
 			this._initializing.addUpdate(new Update("Initializing", ""));
 			appTracker.addApp(this);
@@ -544,10 +488,6 @@ export class App {
 						this._initializing.addUpdate(new Update(body.message || 'Initialization failed', ""));
 						this._initializing.addUpdate(new Update("error", ""));
 						this._initializing.addUpdate(new Update("stop", ""));
-					} else if (!this._uploading.completed) {
-						this._uploading.addUpdate(new Update(body.message || 'File upload failed', ""));
-						this._uploading.addUpdate(new Update("error", ""));
-						this._uploading.addUpdate(new Update("stop", ""));
 					}
 					if (body.snackbar) {
 						if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
@@ -576,135 +516,10 @@ export class App {
 		});
 	}
 
-	private previousCompressionProgress: any
-	private getCompressionProgress() {
-        // If there is an unsigned agreement, do not poll
-        if (Global.user != null && Global.user.unsignedAgreement) {
-            if (!this.failed) {
-				if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
-				setTimeout(() => this.getCompressionProgress(), this.pollingDelay);
-			}
-            return;
-        }
-		const settings = ServerConnection.makeSettings();
-		const url = settings.baseUrl + "optumi/get-launch-compression-progress";
-		const init: RequestInit = {
-			method: 'POST',
-			body: JSON.stringify({
-				uuid: this._uuid,
-			}),
-		};
-		ServerConnection.makeRequest(
-			url,
-			init, 
-			settings
-		).then((response: Response) => {
-			Global.handleResponse(response);
-			if (response.status == 204) {
-				if (!this.failed) {
-					if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
-					setTimeout(() => this.getCompressionProgress(), this.pollingDelay);
-				}
-				return;
-			}
-			return response.json();
-		}).then((body: any) => {
-			if (body) {
-				if (this._initializing.message != "Compressing files") {
-					this._initializing.addUpdate(new Update("Compressing files", ""));
-				}
-				this._initializing.loaded = body.read;
-				this._initializing.total = body.total;
-				if (body.read != 0 && body.read == body.total) {
-                    // Do nothing
-                } else {
-					if (!this.failed) {
-						if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
-						setTimeout(() => this.getCompressionProgress(), this.pollingDelay);
-					}
-				}
-				if (JSON.stringify(body) !== JSON.stringify(this.previousCompressionProgress)) {
-					if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
-					this._changed.emit(this);
-					this.previousCompressionProgress = body
-				}
-			}
-		}, (error: ServerConnection.ResponseError) => {
-			if (!this.failed) {
-				if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
-				setTimeout(() => this.getCompressionProgress(), this.pollingDelay);
-			}
-		});
-	}
-
-	private previousUploadProgress: any
-	private getUploadProgress() {
-        // If there is an unsigned agreement, do not poll
-        if (Global.user != null && Global.user.unsignedAgreement) {
-            if (!this.failed) {
-				if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
-				setTimeout(() => this.getUploadProgress(), this.pollingDelay);
-			}
-            return;
-        }
-		const settings = ServerConnection.makeSettings();
-		const url = settings.baseUrl + "optumi/get-launch-upload-progress";
-		const init: RequestInit = {
-			method: 'POST',
-			body: JSON.stringify({
-				uuid: this._uuid,
-			}),
-		};
-		ServerConnection.makeRequest(
-			url,
-			init, 
-			settings
-		).then((response: Response) => {
-			Global.handleResponse(response);
-			if (response.status == 204) {
-				if (!this.failed) {
-					if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
-					setTimeout(() => this.getUploadProgress(), this.pollingDelay);
-				}
-				return;
-			}
-			return response.json();
-		}).then((body: any) => {
-			if (body) {
-				if (!this._initializing.completed) {
-					this._initializing.total = 0;
-					this._initializing.addUpdate(new Update("stop", ""));
-					this._uploading.addUpdate(new Update("Uploading files", ""));
-				}
-				this._uploading.loaded = body.read;
-				this._uploading.total = body.total;
-				if (body.read != 0 && body.read == body.total) {
-					this._uploading.addUpdate(new Update("stop", ""));
-				} else {
-					if (!this.failed) {
-						if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
-						setTimeout(() => this.getUploadProgress(), this.pollingDelay);
-					}
-				}
-				if (JSON.stringify(body) !== JSON.stringify(this.previousUploadProgress)) {
-					if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
-					this._changed.emit(this);
-					this.previousUploadProgress = body
-				}
-			}
-		}, (error: ServerConnection.ResponseError) => {
-			if (!this.failed) {
-				if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
-				setTimeout(() => this.getUploadProgress(), this.pollingDelay);
-			}
-		});
-	}
-
 	// Convert and send a python notebook to the REST interface for deployment
 	private async launchNotebook() {
 		const uploadFiles: FileUploadConfig[] = this._config.upload.files;
 		const requirements: string = this._config.upload.requirements;
-		const compressFiles = Global.user.compressFilesEnabled;
 
 		var data: any = {};
 
@@ -722,7 +537,6 @@ export class App {
 				data.dataFiles.push(uploadEntry.path);
 			}
 		}
-		data.compress = compressFiles;
 
 		data.uuid = this._uuid;
 		data.notebook = {
@@ -743,52 +557,54 @@ export class App {
 			settings
 		).then((response: Response) => {
 			Global.handleResponse(response);
+			// TODO:JJ Take a look at this
+			this._initializing.addUpdate(new Update("stop", ""));
 		}, (error: ServerConnection.ResponseError) => {
+			// TODO:JJ Take a look at this
 			this._initializing.addUpdate(new Update('Initialization failed', ""));
 			this._initializing.addUpdate(new Update('error', ""));
 			this._initializing.addUpdate(new Update('stop', ""));
 		});
 		this.getLaunchStatus();
-		if (compressFiles && data.dataFiles.length != 0) this.getCompressionProgress();
-		this.getUploadProgress();
 	}
 
 	getAppStatus(): Status {
-		if (this.initializing.error && !this.uploading.started) return Status.COMPLETED;
-		if (this.uploading.error && !this.requisitioning.started) return Status.COMPLETED;
-		if (this.requisitioning.error && !this.running.started) return Status.COMPLETED;
+		if (this.initializing.error && !this.preparing.started) return Status.COMPLETED;
+		if (this.preparing.error && !this.running.started) return Status.COMPLETED;
 		for (var mod of this._modules) {
 			if (mod.modStatus == Status.RUNNING) return Status.RUNNING;
 		}
 		if (this.running.completed) return Status.COMPLETED;
-		if (this.uploading.completed) return Status.RUNNING;
+		if (this.preparing.completed) return Status.RUNNING;
 		return Status.INITIALIZING;
 	}
 
 	getAppMessage(): string {
 		var message = "";
 		if (this._initializing.message != "") message = this._initializing.message;
-		if (this._uploading.message != "") message = this._uploading.message;
-		if (this._requisitioning.message != "") message = this._requisitioning.message;
-		if (this._running.message != "") message = this._running.message;
-		// We will say a session is starting until we can connect to it
-		if (this.interactive && message == 'Running' && !(this.modules.length > 0 && this.modules[0].sessionReady)) return 'Starting';
-		// We call a terminated app 'closed'
-		if (this.interactive && message == 'Terminated') return 'Closed';
+		if (this._preparing.message != "") message = this._preparing.message;
+		if (this._running.message != "") message = this.adjustMessage(this._running.message);
 		return message;
     }
     
+	adjustMessage(message: string): string {
+		// We will say a session is starting until we can connect to it
+		if (this.interactive && message == 'Running' && !(this.modules.length > 0 && this.modules[0].sessionReady)) return 'Connecting';
+		// We call a terminated app 'closed'
+		if (this.interactive && message == 'Terminating') return 'Closing';
+		if (this.interactive && message == 'Terminated') return 'Closed';
+		return message;
+	}
+
     getTimeElapsed(): string {
         if (!this._initializing.completed) return undefined;
-		if (!this._uploading.completed) return undefined;
-		if (!this._requisitioning.completed) return undefined;
+		if (!this._preparing.completed) return undefined;
         return this._running.elapsed;
 	}
 	
 	getEndTime(): Date {
 		if (!this._initializing.completed) return undefined;
-		if (!this._uploading.completed) return undefined;
-		if (!this._requisitioning.completed) return undefined;
+		if (!this._preparing.completed) return undefined;
         return this._running.endTime;
 	}
 
@@ -809,33 +625,16 @@ export class App {
 			const seconds = +split[1];
 			const cost = ((minutes * rate / 60) + (seconds * rate / 3600));
 			return (cost.toFixed(2) == '0.00' ? '< $0.01' : '~ $' + cost.toFixed(2));
-		} 
+		}
     }
 
 	getShowLoading(): boolean {
-		if (this._running.started) return this._running.loaded != this._running.total;
-		if (this._requisitioning.started) return this._requisitioning.loaded != this._requisitioning.total;
-		if (this._uploading.started) return this._uploading.loaded != this._uploading.total;
-		if (this._initializing.started) return this._initializing.loaded != this._initializing.total;
+		if (this._running.started) return false;
+		if (this._preparing.started) return this._preparing.message == 'Waiting for cloud provider';
+		if (this._initializing.started) return false;
 		return false;
 	}
 
-	getPercentLoaded(): number {
-		if (!this._initializing.completed) return undefined;
-		if (!this._uploading.completed) return this._uploading.total == -1 ? undefined : this._uploading.loaded / this._uploading.total;
-		if (!this._requisitioning.completed) return this._requisitioning.total == -1 ? undefined : this._requisitioning.loaded / this._requisitioning.total;
-		if (!this._running.completed) return this._running.total == -1 ? undefined : this._running.loaded / this._running.total;
-		return undefined;
-	}
-
-	getLoadingTooltip(): string {
-		if (!this.getShowLoading()) return undefined;
-		if (!this._initializing.completed) return this._initializing.loaded + '/' + this._initializing.total + ' files';
-		if (!this._uploading.completed) return this._uploading.total == -1 ? '' : FormatUtils.styleCapacityUnitValue()(this._uploading.loaded) + '/' + FormatUtils.styleCapacityUnitValue()(this._uploading.total);
-		if (!this._requisitioning.completed) return this._requisitioning.total == -1 ? '' : FormatUtils.styleCapacityUnitValue()(this._requisitioning.loaded / Math.pow(1024, 2)) + '/' + FormatUtils.styleCapacityUnitValue()(this._requisitioning.total / Math.pow(1024, 2));
-		if (!this._running.completed) return this._running.total == -1 ? '' : FormatUtils.styleCapacityUnitValue()(this._running.loaded / Math.pow(1024, 2)) + '/' + FormatUtils.styleCapacityUnitValue()(this._running.total / Math.pow(1024, 2));
-	}
-
 	getError() {
 		if (this.failed) {
 			return true;
