@@ -96,14 +96,12 @@ export class AppTracker {
         }
 		const uuids: string[] = [];
 		const lastInitializingLines: number[] = [];
-		const lastUploadingLines: number[] = [];
-		const lastRequisitioningLines: number[] = [];
+		const lastPreparingLines: number[] = [];
 		const lastRunningLines: number[] = [];
 		for (var app of this.activeJobsOrSessions) {
 			uuids.push(app.uuid);
 			lastInitializingLines.push(app.initializing.length);
-			lastUploadingLines.push(app.uploading.length);
-			lastRequisitioningLines.push(app.requisitioning.length);
+			lastPreparingLines.push(app.preparing.length);
 			lastRunningLines.push(app.running.length);
 		}
 		// There is no need to make an empty request
@@ -115,8 +113,7 @@ export class AppTracker {
 				body: JSON.stringify({
 					uuids: uuids,
 					lastInitializingLines: lastInitializingLines,
-					lastUploadingLines: lastUploadingLines,
-					lastRequisitioningLines: lastRequisitioningLines,
+					lastPreparingLines: lastPreparingLines,
 					lastRunningLines: lastRunningLines,
 				}),
 			};
