@@ -93,11 +93,11 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
     }
 
     private openSession = () => {
-        window.open('http://localhost:' + this.props.app.sessionPort + '?token=' + this.props.app.sessionToken, '_blank');
+        window.open('http://' + window.location.hostname + ':' + this.props.app.sessionPort + '?token=' + this.props.app.sessionToken, '_blank');
     }
 
     private openAsNewNotebook = () => {
-        const path = this.props.app.path.replace('.ipynb', '-run' + (this.props.app.runNum) + '.ipynb');
+        const path = this.props.app.path.replace('.ipynb', '-' + (this.props.app.annotationOrRunNum.replace(/\W/g, '')) + '.ipynb');
         var notebook: any = this.props.app.notebook;
         FileServerUtils.saveNotebook(path, notebook).then((success: boolean) => { Global.docManager.open(path) });
         // Close the dialog
@@ -107,6 +107,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         var i = 0;
+        const app = this.props.app;
         return (
             <>
                 <IconButton
@@ -151,27 +152,27 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                             paddingRight: '12px', // this is 6px counteracting the MuiDialogTitle padding and 6px aligning the padding to the right of the tabs
                         }}>
                             <div style={{margin: 'auto', paddingLeft: '12px'}}>
-            					{this.props.app.interactive ? "Session" : "Job"}
+            					{app.interactive ? "Session" : "Job"}
                             </div>
                         </div>
 						<div style={{width: '100%', display: 'inline-flex', overflowX: 'hidden', fontSize: '16px', paddingLeft: '8px'}}>
 	                        <div style={{flexGrow: 1, margin: 'auto 0px'}}>
-                                {this.props.app.path}
+                                {app.path}
                             </div>
-                            {this.props.app.interactive && (
+                            {app.interactive && (
                                 <Button
                                     style={{margin: '6px'}}
                                     disableElevation
                                     variant='contained'
                                     color='primary'
                                     onClick={this.openSession}
-                                    disabled={this.props.app.getAppStatus() == Status.COMPLETED || !(this.props.app.modules.length > 0 && this.props.app.modules[0].sessionReady)}
+                                    disabled={app.getAppStatus() == Status.COMPLETED || !(app.modules.length > 0 && app.modules[0].sessionReady)}
                                     endIcon={<OpenInNewIcon />}
                                 >
                                     Open session
                                 </Button>
                             )}
-                            {!this.props.app.interactive && (
+                            {!app.interactive && (
                                 <ExtraInfo reminder='Create as a new notebook' >
                                     <Button
                                         style={{margin: '6px'}}
@@ -179,10 +180,10 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                         variant='contained'
                                         color='primary'
                                         onClick={this.openAsNewNotebook}
-                                        disabled={this.props.app.getAppStatus() != Status.COMPLETED}
+                                        disabled={app.getAppStatus() != Status.COMPLETED}
                                         endIcon={<OpenInNewIcon />}
                                     >
-                                        Create
+                                        Save + Open
                                     </Button>
                                 </ExtraInfo>
                             )}
@@ -229,7 +230,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                             }}
                                             value={Page.SUMMARY}
                                         />
-                                        {!this.props.app.interactive && <Tab
+                                        {!app.interactive && <Tab
                                             label='NOTIFICATIONS'
                                             style={{
                                                 padding: '0px',
@@ -238,7 +239,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                             }}
                                             value={Page.NOTIFICATIONS}
                                         />}
-                                        {!this.props.app.interactive && <Tab
+                                        {!app.interactive && <Tab
                                             label='NOTEBOOK'
                                             style={{
                                                 padding: '0px',
@@ -265,7 +266,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                             }}
                                             value={Page.MACHINE}
                                         />
-                                        {this.props.app.modules.length > 0 && /*this.props.app.interactive &&*/ <Tab
+                                        {app.modules.length > 0 && /*app.interactive &&*/ <Tab
                                             label='TERMINAL'
                                             style={{
                                                 padding: '0px',
@@ -293,68 +294,68 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                             }}>
                                 {this.state.selectedPanel == Page.SUMMARY ? (
                                     <div style={{padding: '20px'}}>
-                                        {this.props.app.interactive ? 'Session' : 'Job'} launched at {this.props.app.timestamp.toLocaleTimeString('en-US', { 
+                                        {app.interactive ? 'Session' : 'Job'} launched at {app.timestamp.toLocaleTimeString('en-US', { 
                                             hour: 'numeric', minute: 'numeric',
-                                        })} on {this.props.app.timestamp.toLocaleDateString('en-US', { 
+                                        })} on {app.timestamp.toLocaleDateString('en-US', { 
                                             weekday: 'long', year: 'numeric', month: 'long', day: 'numeric' 
                                         })}
                                         <br/>
-                                        {this.props.app.runNum ? (
+                                        {app.runNum ? (
                                             <>
-                                                Run #{this.props.app.runNum + (this.props.app.config.annotation != '' ? ': ' + this.props.app.config.annotation : '')}<br/>
+                                                Run #{app.runNum + (app.config.annotation != '' ? ': ' + app.config.annotation : '')}<br/>
                                             </>
                                         ) : (
                                             <></>
                                         )}
-                                        {this.props.app.getTimeElapsed() ? (
+                                        {app.getTimeElapsed() ? (
                                             <>
-                                                Duration: {this.props.app.getTimeElapsed()}<br/>
+                                                Duration: {app.getTimeElapsed()}<br/>
                                             </>
                                         ) : (
                                             <></>
                                         )}
-                                        {this.props.app.getCost() ? (
+                                        {app.getCost() ? (
                                             <>
-                                                Estimated cost: {this.props.app.getCost()}<br/>
+                                                Estimated cost: {app.getCost()}<br/>
                                             </>
                                         ) : (
                                             <></>
                                         )}
                                         <br/>
                                         {/* The must have unique key error apparently applies to fragments as well, despite not being able to hold keys */}
-                                        {(this.props.app.initializing.messages + this.props.app.uploading.messages + this.props.app.requisitioning.messages + this.props.app.running.messages).split('\n').map((value: string) => (<span style={{whiteSpace: 'pre'}} key={value + i++}>{value}<br /></span>))}
+                                        {(app.initializing.messages + app.preparing.messages + app.running.messages).split('\n').map((value: string) => (<span style={{whiteSpace: 'pre'}} key={value + i++}>{app.adjustMessage(value)}<br /></span>))}
                                     </div>
                                 ) : this.state.selectedPanel == Page.NOTIFICATIONS ? (
                                     <div style={{padding: '20px'}}>
                                         <NotificationContent 
-                                            getValue={() => this.props.app.config}
-                                            saveValue={(config: OptumiConfig) => this.props.app.config = config}
-                                            disabled={this.props.app.getAppStatus() == Status.COMPLETED}
+                                            getValue={() => app.config}
+                                            saveValue={(config: OptumiConfig) => app.config = config}
+                                            disabled={app.getAppStatus() == Status.COMPLETED}
                                             openUserDialogTo={this.props.openUserDialogTo}
                                             handleClose={this.handleClose}
                                         />
                                     </div>
                             ) : this.state.selectedPanel == Page.NOTEBOOK ? (
                                     <div style={{overflow: 'auto', width: '100%', height: '100%'}}>
-                                        <Notebook notebook={this.props.app.notebook} />
+                                        <Notebook notebook={app.notebook} />
                                     </div>
                                 ) : this.state.selectedPanel == Page.FILES ? (
                                     <div style={{padding: '8px'}}>
-                                        {this.props.app.interactive && this.props.app.getAppStatus() != Status.COMPLETED ? (
+                                        {app.interactive && app.getAppStatus() != Status.COMPLETED ? (
                                             <div style={{padding: '12px'}}>
                                                 Files will appear here after your session has completed. Until then, you can upload/download files directly from the session tab.
                                             </div>
                                         ) : (
-                                            <OutputFileList app={this.props.app} />
+                                            <OutputFileList app={app} />
                                         )}
                                     </div>
                                 ) : this.state.selectedPanel == Page.MACHINE ? (
                                     <div style={{padding: '14px 8px'}}>
-                                         {this.props.app.machine ? (
-									        <MachineCapability machine={this.props.app.machine} />
+                                         {app.machine ? (
+									        <MachineCapability machine={app.machine} />
                                         ) : (
                                             <div style={{padding: '6px 12px'}}>
-                                                Machine information will appear when the {this.props.app.interactive ? ' session ' : ' job '} starts.
+                                                Machine information will appear when the {app.interactive ? ' session ' : ' job '} starts.
                                             </div>
                                         )}
                                     </div>
@@ -363,7 +364,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                     <div style={{overflow: 'hidden', width: '100%', height: '100%'}}>
                                         <ScrollableDiv
                                             key='output'
-                                            source={Object.assign([], this.props.app.modules[0].output)}
+                                            source={Object.assign([], app.modules[0].output)}
                                             autoScroll={true}
                                         />
                                     </div>
