@@ -12,12 +12,17 @@ import ExtraInfo from '../../utils/ExtraInfo';
 import FormatUtils from '../../utils/FormatUtils';
 import { Machine, NoMachine } from './Machine';
 
-const GraphicsBar = withStyles(forBar('Graphics')) (Slider);
-const ComputeBar = withStyles(forBar('Compute')) (Slider);
-const MemoryBar = withStyles(forBar('Memory')) (Slider);
-const DiskBar = withStyles(forBar('Disk')) (Slider);
+const GraphicsBar = withStyles(forBar('Graphics', false)) (Slider);
+const ComputeBar = withStyles(forBar('Compute', false)) (Slider);
+const MemoryBar = withStyles(forBar('Memory', false)) (Slider);
+const DiskBar = withStyles(forBar('Disk', false)) (Slider);
 
-function forBar(type: string): any {
+const EmptyGraphicsBar = withStyles(forBar('Graphics', true)) (Slider);
+const EmptyComputeBar = withStyles(forBar('Compute', true)) (Slider);
+const EmptyMemoryBar = withStyles(forBar('Memory', true)) (Slider);
+const EmptyDiskBar = withStyles(forBar('Disk', true)) (Slider);
+
+function forBar(type: string, empty: boolean): any {
     var color: string, trackRadius: string, railRadius: string
     if (type == 'Graphics') {
         color = '#ffba7d';
@@ -28,17 +33,17 @@ function forBar(type: string): any {
         trackRadius = '0px 4px 4px 0px';
         railRadius = '0px';
     } else if (type == 'Memory') {
-        color = '#afaab0';
+        color = '#ba9fd1';
         trackRadius = '0px 4px 4px 0px';
         railRadius = '0px';
     } else if (type == 'Disk') {
-        color = '#68da7c';
+        color = '#7cdf8e';
         trackRadius = '0px 4px 4px 4px';
         railRadius = '0px 0px 4px 4px';
     }
     return {
         root: {
-            marginRight: '4px',
+            marginRight: '6px',
             height: type == 'Disk' ? '14px' : '13px',
             width: '100%',
             padding: '0px',
@@ -66,6 +71,7 @@ function forBar(type: string): any {
             boxSizing: 'border-box',
             border: "1px solid " + darken(color, 0.25),
             borderRadius: trackRadius,
+            opacity: empty ? 0 : 1,
         },
         rail: { // right side
             // display: 'none',
@@ -84,7 +90,7 @@ interface IState {}
 
 const FONT_SIZE = '12px'
 const COLUMN_WIDTH_1 = '30px'
-const COLUMN_WIDTH_2 = '52px'
+const COLUMN_WIDTH_2 = '55px'
 const COLUMN_MARGIN = '1px 0px 0px 0px'
 
 export class IdentityMachineComponent extends React.Component<IProps, IState> {
@@ -97,12 +103,16 @@ export class IdentityMachineComponent extends React.Component<IProps, IState> {
             <ExtraInfo reminder={title}>
                 <div style={{width: '100%', lineHeight: '9px'}}>
                     <div style={{width: '100%', display: 'inline-flex'}}>
-                        <GraphicsBar
-                            value={machine.graphicsRating}
-                            max={1}
-                            step={0.01}
-                            disabled
-                        />
+                        {machine.graphicsRating > 0 ? (
+                            <GraphicsBar
+                                value={machine.graphicsRating}
+                                max={1}
+                                step={0.01}
+                                disabled
+                            />
+                        ) : (
+                            <EmptyGraphicsBar disabled />
+                        )}
                         <div style={{minWidth: COLUMN_WIDTH_1, margin: COLUMN_MARGIN, fontSize: FONT_SIZE, lineHeight: FONT_SIZE}}>
                             GPU
                         </div>
@@ -111,26 +121,34 @@ export class IdentityMachineComponent extends React.Component<IProps, IState> {
                         </div>
                     </div>
                     <div style={{width: '100%', display: 'inline-flex'}}>
-                        <ComputeBar
-                            value={machine.computeRating}
-                            max={1}
-                            step={0.01}
-                            disabled
-                        />
+                        {machine.computeRating > 0 ? (
+                            <ComputeBar
+                                value={machine.computeRating}
+                                max={1}
+                                step={0.01}
+                                disabled
+                            />
+                        ) : (
+                            <EmptyComputeBar disabled />
+                        )}
                         <div style={{minWidth: COLUMN_WIDTH_1, margin: COLUMN_MARGIN, fontSize: FONT_SIZE, lineHeight: FONT_SIZE}}>
                             CPU
                         </div>
                         <div style={{minWidth: COLUMN_WIDTH_2, textAlign: 'right', margin: COLUMN_MARGIN, fontSize: FONT_SIZE, lineHeight: FONT_SIZE}}>
-                            {machine.computeCores} core
+                            {machine.computeCores == 1 ? machine.computeCores + ' core' : machine.computeCores + ' cores'}
                         </div>
                     </div>
                     <div style={{width: '100%', display: 'inline-flex'}}>                
-                        <MemoryBar
-                            value={machine.memoryRating}
-                            max={1}
-                            step={0.01}
-                            disabled
-                        />
+                        {machine.memoryRating > 0 ? (
+                            <MemoryBar
+                                value={machine.memoryRating}
+                                max={1}
+                                step={0.01}
+                                disabled
+                            />
+                        ) : (
+                            <EmptyMemoryBar disabled />
+                        )}
                         <div style={{minWidth: COLUMN_WIDTH_1, margin: COLUMN_MARGIN, fontSize: FONT_SIZE, lineHeight: FONT_SIZE}}>
                             RAM
                         </div>
@@ -139,12 +157,16 @@ export class IdentityMachineComponent extends React.Component<IProps, IState> {
                         </div>
                     </div>
                     <div style={{width: '100%', display: 'inline-flex'}}>                
-                        <DiskBar
-                            value={machine.storageRating}
-                            max={1}
-                            step={0.01}
-                            disabled
-                        />
+                        {machine.storageRating > 0 ? (
+                            <DiskBar
+                                value={machine.storageRating}
+                                max={1}
+                                step={0.01}
+                                disabled
+                            />
+                        ) : (
+                            <EmptyDiskBar disabled />
+                        )}
                         <div style={{minWidth: COLUMN_WIDTH_1, margin: COLUMN_MARGIN, fontSize: FONT_SIZE, lineHeight: FONT_SIZE}}>
                             DISK
                         </div>
