@@ -123,7 +123,7 @@ export class MachineComponent extends React.Component<IProps, IState> {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         var machine: Machine = this.props.machine
         var tags: JSX.Element[] = []
-        var machineState: string = Machine.getStateMessage(this.props.machine.state);
+        var machineState: string = this.props.machine.getStateMessage();
         if (machineState != '') {
             tags.push(
                 <ExtraInfo key={'machineState'} reminder='Status'>
@@ -152,7 +152,7 @@ export class MachineComponent extends React.Component<IProps, IState> {
                                         const appWord = app.interactive ? "session" : "job";
                                         const appAction = app.interactive ? "closed" : "terminated";
                                         // if (app is running) {
-                                        if ((app.requisitioning.completed && !app.requisitioning.error) && !app.running.completed) {
+                                        if ((app.preparing.completed && !app.preparing.error) && !app.running.completed) {
                                             return "Your " + appWord + " '" +  app.name + "' (" + app.annotationOrRunNum + ") is active on this machine. It will be " + appAction + " if the machine is released."
                                         } else {
                                             return "Your " + appWord + " '" +  app.name + "' (" + app.annotationOrRunNum + ") is waiting for this machine. It will be deleted if the machine is released."
@@ -165,7 +165,7 @@ export class MachineComponent extends React.Component<IProps, IState> {
                                         const appWord = app.interactive ? "session" : "job";
                                         const appAction = app.interactive ? "closed" : "terminated";
                                         // if (app is running) {
-                                        if ((app.requisitioning.completed && !app.requisitioning.error) && !app.running.completed) {
+                                        if ((app.preparing.completed && !app.preparing.error) && !app.running.completed) {
                                             return "Your " + appWord + " '" +  app.name + "' (" + app.annotationOrRunNum + ") is active on this machine. It will be " + appAction + " if the machine is released."
                                         } else {
                                             return "Your " + appWord + " '" +  app.name + "' (" + app.annotationOrRunNum + ") is waiting for this machine. It will be deleted if the machine is released."
@@ -190,7 +190,7 @@ export class MachineComponent extends React.Component<IProps, IState> {
                                         for (var app of user.appTracker.activeJobsOrSessions) {
                                             if (app.uuid == machine.app) {
                                                 // if (app is running) {
-                                                if ((app.requisitioning.completed && !app.requisitioning.error) && !app.running.completed) {
+                                                if ((app.preparing.completed && !app.preparing.error) && !app.running.completed) {
                                                     // Only delete the machine after the job is stopped to avoid a race condition
                                                     // We set these outside so they will span the job stop/delete as well
                                                     this.safeSetState({ waiting: true, spinning: false });
