@@ -6,7 +6,6 @@
 **/
 
 import { ServerConnection } from '@jupyterlab/services';
-import { PageConfig } from '@jupyterlab/coreutils';
 
 export default class FileServerUtils {
 	// Return two booleans, the first is if the path exists, the second is if it is a file (true) or directory (false)
@@ -75,32 +74,6 @@ export default class FileServerUtils {
 		return files;
 	}
 
-	public static async convertFile(path: string): Promise<string> {
-		const settings = ServerConnection.makeSettings();
-		const url = PageConfig.getNBConvertURL({
-			format: 'script',
-			download: false,
-			path: path
-		});
-		const init: RequestInit = {
-			method: 'GET',
-		};
-		const response = ServerConnection.makeRequest(
-			url,
-			init, 
-			settings
-		).then((response: Response) => {
-			if (response.status !== 200 && response.status !== 201) {
-				return Promise.resolve("Unable to convert notebook file: " + path);
-			}
-			return response.text();
-		}).then((message: string) => {
-			return message;
-		});
-		
-		return response;
-	}
-
 	public static async saveNotebook(path: string, notebook: any): Promise<boolean> {
 		const settings = ServerConnection.makeSettings();
 		const url = settings.baseUrl + "api/contents/" + path;
